******************************************************************************** 
                                                  
********************************************************************************
/*                                Path                                        */
global path1 
/*******************************************************************************
                              Base Data Set
*******************************************************************************/ 
clear all
import excel "${path1}\Bases\Other\Date.xlsx", sheet("Date 2015-2021") firstrow
tostring date, gen(datemdy) 
destring datemdy, replace 
format datemdy %td
drop date
count if datemdy == 22200
gen year = year(datemdy)
gen month = month(datemdy)
gen quarter = .
replace quarter = 1 if month == 1 | month == 2 | month == 3
replace quarter = 2 if month == 4 | month == 5 | month == 6
replace quarter = 3 if month == 7 | month == 8 | month == 9
replace quarter = 4 if month == 10 | month == 11 | month == 12
drop if iso_code == "" 
save "${path1}\Bases\Intermediate\IsoCodeDate.dta", replace

********************************************************************************  
/*******************************************************************************
                         Changes initial databases
*******************************************************************************/ 
********************************************************************************                                              
********************************************************************************
/*                     Health Data, Our World in Data                         */
clear all
*Import Health data 
import delimited "${path1}\Bases\Health&Containment\CovidData-OurWorldinData-23.2.21.csv"
*Drop values for world numbers 
drop if missing(continent)
*Date format 
gen datemdy = date(date,"MDY")
format datemdy %td
gen year = year(datemdy)
gen month=month(datemdy)
order iso_code location year datemdy date 
sort iso_code year datemdy
drop if length(iso_code) > 3
*
drop if year < 2015
drop if iso_code == "SHN"
drop date
drop continent location
save "${path1}\Bases\Intermediate\CovidData-OurWorldinData-23.2.21.dta", replace
********************************************************************************
/*                              BCI, OECD                                     */
clear all
use "${path1}\Bases\Other\BCI-04.15.21.dta", clear
*Gen date variable with year - month. 15 added using R 
gen datemdy=date(date,"YMD")
format datemdy %td
gen year=year(datemdy)
gen month=month(datemdy)
gen quarter = .
replace quarter = 1 if month == 1 | month == 2 | month == 3
replace quarter = 2 if month == 4 | month == 5 | month == 6
replace quarter = 3 if month == 7 | month == 8 | month == 9
replace quarter = 4 if month == 10 | month == 11 | month == 12
sort iso_code year datemdy
order iso_code year datemdy BCI 
sort iso_code year datemdy
drop if iso_code == "G-7"
drop if iso_code == "OECDE"
drop if iso_code == "OECD"
drop if iso_code == "EA19"
drop if length(iso_code) > 3
drop if year<2015 
drop date
save "${path1}\Bases\Intermediate\BCI-04.15.21-short.dta", replace
********************************************************************************
/*                         BIS Monetary Policy ir                          */
clear all
import delimited "${path1}\Bases\Fiscal&Monetary\BIS_ir-3.17.21.csv", case(preserve) 
drop v1
gen year = substr(Date,4,6)
gen month = substr(Date,1,2)
destring month, replace 
destring year, replace 
drop Date
drop if length(iso_code) > 3
drop if length(iso_code) > 3
sort iso_code year month 
drop if year<2015
save "${path1}\Bases\Intermediate\BIS_ir-3.17.21.dta", replace 
********************************************************************************
/*                         BIS Monetary Policy ir  USA                        */
clear all
import delimited "${path1}\Bases\Fiscal&Monetary\BIS_ir_USA-3.20.21.csv", case(preserve) 
drop v1
gen year = substr(Date,4,6)
gen month = substr(Date,1,2)
destring month, replace 
destring year, replace 
drop Date
drop if length(iso_code) > 3
drop if length(iso_code) > 3
sort iso_code year month 
drop if year<2015
sort iso_code year month 
drop iso_code
save "${path1}\Bases\Intermediate\BIS_ir_USA-3.20.21.dta", replace 

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
/*                         IMF Monetary Policy ir                          */
clear all
import delimited "${path1}\Bases\Fiscal&Monetary\ir.IMF_04-27-21", case(preserve) 
drop v1
gen year = substr(Date,4,6)
gen month = substr(Date,1,2)
destring month, replace 
destring year, replace 
drop Date
drop if length(iso_code) > 3
drop if length(iso_code) > 3
sort iso_code year month 
drop if year<2015
save "${path1}\Bases\Intermediate\ir.IMF_04-27-21.dta", replace 
********************************************************************************
/*                         IMF Monetary Policy ir USA                       */
clear all
use "${path1}\Bases\Intermediate\ir.IMF_04-27-21.dta", clear
keep if iso_code == "USA"
ren ir_IMF ir_IMF_USA
save "${path1}\Bases\Intermediate\ir.IMF-USA_04-27-21.dta", replace 
********************************************************************************
/*                         IMF Monetary Policy ir CRI                         */
clear all
use "${path1}\Bases\Intermediate\ir.IMF_04-27-21.dta", clear
keep if iso_code == "CRI"
ren ir_IMF ir_IMF_CRI
save "${path1}\Bases\Intermediate\ir.IMF-CRI_04-27-21.dta", replace 
********************************************************************************
/*                       BIS Monetary Policy ir Euro Area                     */
clear all
use "${path1}\Bases\Intermediate\BIS_ir-3.17.21.dta", clear
keep if iso_code == "AUT" | iso_code == "BEL" | iso_code == "DEU" | iso_code == "ESP" | iso_code == "EST" | iso_code == "FIN" | iso_code == "FRA" | iso_code == "GRC" | iso_code == "IRL" | iso_code == "ITA" | iso_code == "LTU" | iso_code == "LUX" | iso_code == "LVA" | iso_code == "NLD" | iso_code == "PRT" | iso_code == "SVK" | iso_code == "SVN" | iso_code == "CYP" | iso_code == "MLT"
ren BIS_ir BIS_ir_EUROAREA
save "${path1}\Bases\Intermediate\ir.IMF-EUROAREA_04-27-21.dta", replace 
********************************************************************************
********************************************************************************
********************************************************************************

********************************************************************************
/*                         Government Final Cunsumption                       */
clear all
import delimited "${path1}\Bases\Fiscal&Monetary\OECD_Gov_FinalConsumption_LC-03.18.21.csv", case(preserve) 
drop v1
gen year = substr(Date,4,6)
gen Q = substr(Date,1,2)
gen quarter = .
replace quarter = 1 if Q == "Q1"
replace quarter = 2 if Q == "Q2"
replace quarter = 3 if Q == "Q3"
replace quarter = 4 if Q == "Q4"
destring quarter, replace 
destring year, replace 
drop Date
drop Q
drop if iso_code == "."
sort iso_code year quarter
drop if year < 2015   
save "${path1}\Bases\Intermediate\OECD_Gov_FinalConsumption_LC-03.18.21.dta", replace 
********************************************************************************
/*               Government Final Cunsumption % GDP CHN                       */
*https://databank.worldbank.org/reports.aspx?source=2&series=NE.CON.GOVT.ZS&country=CHN#
clear all
import excel "${path1}\Bases\Fiscal&Monetary\GovConsump_CHN.xlsx", sheet("Data") firstrow  clear
drop in 7/10
ren (CountryCode Time) (iso_code year)
destring Generalgovernmentfinalconsump, replace force
gen Gov_Final_Cons_GDP_CHN = Generalgovernmentfinalconsump / 100
drop Generalgovernmentfinalconsump
keep iso_code year Gov_Final_Cons_GDP_CHN 
save "${path1}\Bases\Intermediate\Gov_Final_Cons_GDP_CHN-04.27.21.dta", replace 
********************************************************************************
/*                               Quarterly GDP                                */
clear all
import delimited "${path1}\Bases\Fiscal&Monetary\OECD_Quarterly_GDP_LC-3.19.21.csv", case(preserve) 
drop v1
gen year = substr(Date,1,4)
gen Q = substr(Date,6,7)
gen quarter = .
replace quarter = 1 if Q == "Q1"
replace quarter = 2 if Q == "Q2"
replace quarter = 3 if Q == "Q3"
replace quarter = 4 if Q == "Q4"
destring quarter, replace 
destring year, replace 
drop Date
drop Q
drop if iso_code == "."
drop if length(iso_code) > 3
sort iso_code year quarter
drop if year < 2015   
save "${path1}\Bases\Intermediate\OECD_Quarterly_GDP_LC-3.19.21.dta", replace          
********************************************************************************
/*                      Inflation Average USA                                */
clear all
use "${path1}\Bases\Fiscal&Monetary\WEO_Inflation_Average-3.13.21.dta", clear
keep if iso_code == "USA" 
rename Inflation_Average Inflation_Average_USA
keep year Inflation_Average_USA     
drop if year < 2015        
drop if year > 2021       
save "${path1}\Bases\Intermediate\InflationAverageUSA-3.13.21.dta", replace  
********************************************************************************
/*                            Policy Tracker                                  */
*Political Tracker
clear all
import delimited "${path1}\Bases\Health&Containment\OxCGRT_latest-2.24.21.csv", stringcols(3 4) 
tostring date, replace format(%20.0f)
gen datemdy = date(date,"YMD")
format datemdy %td
gen year = year(datemdy)
gen month=month(datemdy)
order year month datemdy, after(date)
drop countryname regionname regioncode 
*Dropeo states
drop if jurisdiction == "STATE_TOTAL"
drop jurisdiction
rename countrycode iso_code
order iso_code year datemdy 
sort iso_code year datemdy 
drop date
save "${path1}\Bases\Intermediate\OxCGRT_latest-2.24.21.dta", replace
********************************************************************************
/*                         Women in Parliament                                */
*Women in Legislature * Chequeado, actualizado 24.3.21  
clear all
import excel "${path1}\Bases\Political\WomeninPalament_24.3.21.xlsx", sheet("Data") firstrow
rename CountryCode iso_code 
rename Time year
drop TimeCode
sort iso_code year
*drop title
drop in 1/5
drop CountryName
destring year, replace 
recast float year
destring Proportionofseatsheldbywome, replace force
rename Proportionofseatsheldbywome WomeninParliament
sort iso_code year
order iso_code year WomeninParliament
by iso_code: gen WomeninParliament_Lag = WomeninParliament[_n-1]
drop if year < 2015 | iso_code == "ARB"
save "${path1}\Bases\Intermediate\WomeninParliament_2.23.21.dta", replace
********************************************************************************
/*                             Heritage                                       */
clear all
import excel "${path1}\Bases\Political\Heritage_5.1.21.xlsx", sheet("data (1)") firstrow
keep if Name == "Australia" | Name == "Austria" | Name == "Belgium" | Name == "Brazil" | Name == "Canada" | Name == "Sweden" | Name == "Chile" | Name == "China" | Name == "Colombia" | Name == "Costa Rica" | Name == "Czech Republic" | Name == "Germany" | Name == "Denmark" | Name == "Spain" | Name == "Estonia" | Name == "Finland" | Name == "France" | Name == "United Kingdom" | Name == "Greece" | Name == "Hungary" | Name == "Indonesia" | Name == "India" | Name == "Ireland" | Name == "Israel" | Name == "Italy" | Name == "Japan" | Name == "South Korea" | Name == "Lithuania" | Name == "Luxembourg" | Name == "Latvia" | Name == "Mexico" | Name == "Netherlands" | Name == "Norway" | Name == "New Zealand" | Name == "Poland" | Name == "Portugal" | Name == "Russia" | Name == "Slovak Republic" | Name == "Slovenia" | Name == "Switzerland" | Name == "Turkey" | Name == "United States" | Name == "South Africa"
gen iso_code = "." 
order Name iso_code
replace iso_code = "AUS" if Name == "Australia"
replace iso_code = "AUT" if Name == "Austria"
replace iso_code = "BEL" if Name == "Belgium" 
replace iso_code = "BRA" if Name == "Brazil" 
replace iso_code = "CAN" if Name == "Canada" 
replace iso_code = "CHE" if Name == "Switzerland" 
replace iso_code = "CHL" if Name == "Chile" 
replace iso_code = "CHN" if Name == "China" 
replace iso_code = "COL" if Name == "Colombia" 
replace iso_code = "CRI" if Name == "Costa Rica" 
replace iso_code = "CZE" if Name == "Czech Republic" 
replace iso_code = "DEU" if Name == "Germany" 
replace iso_code = "DNK" if Name == "Denmark" 
replace iso_code = "ESP" if Name == "Spain" 
replace iso_code = "EST" if Name == "Estonia" 
replace iso_code = "FIN" if Name == "Finland" 
replace iso_code = "FRA" if Name == "France" 
replace iso_code = "GBR" if Name == "United Kingdom" 
replace iso_code = "GRC" if Name == "Greece" 
replace iso_code = "HUN" if Name == "Hungary" 
replace iso_code = "IDN" if Name == "Indonesia" 
replace iso_code = "IND" if Name == "India" 
replace iso_code = "IRL" if Name == "Ireland" 
replace iso_code = "ISR" if Name == "Israel" 
replace iso_code = "ITA" if Name == "Italy" 
replace iso_code = "JPN" if Name == "Japan" 
replace iso_code = "KOR" if Name == "South Korea" 
replace iso_code = "LTU" if Name == "Lithuania" 
replace iso_code = "LUX" if Name == "Luxembourg" 
replace iso_code = "LVA" if Name == "Latvia" 
replace iso_code = "MEX" if Name == "Mexico" 
replace iso_code = "NLD" if Name == "Netherlands" 
replace iso_code = "NOR" if Name == "Norway" 
replace iso_code = "NZL" if Name == "New Zealand" 
replace iso_code = "POL" if Name == "Poland" 
replace iso_code = "PRT" if Name == "Portugal" 
replace iso_code = "RUS" if Name == "Russia" 
replace iso_code = "SVK" if Name == "Slovak Republic" 
replace iso_code = "SVN" if Name == "Slovenia" 
replace iso_code = "SWE" if Name == "Sweden" 
replace iso_code = "TUR" if Name == "Turkey" 
replace iso_code = "USA" if Name == "United States" 
replace iso_code = "ZAF" if Name == "South Africa" 
keep if iso_code == "AUS" | iso_code == "AUT" | iso_code == "BEL" | iso_code == "BRA" | iso_code == "CAN" | iso_code == "CHE" | iso_code == "CHL" | iso_code == "CHN" | iso_code == "COL" | iso_code == "CRI" | iso_code == "CZE" | iso_code == "DEU" | iso_code == "DNK" | iso_code == "ESP" | iso_code == "EST" | iso_code == "FIN" | iso_code == "FRA" | iso_code == "GBR" | iso_code == "GRC" | iso_code == "HUN" | iso_code == "IDN" | iso_code == "IND" | iso_code == "IRL" | iso_code == "ISR" | iso_code == "ITA" | iso_code == "JPN" | iso_code == "KOR" | iso_code == "LTU" | iso_code == "LUX" | iso_code == "LVA" | iso_code == "MEX" | iso_code == "NLD" | iso_code == "NOR" | iso_code == "NZL" | iso_code == "POL" | iso_code == "PRT" | iso_code == "RUS" | iso_code == "SVK" | iso_code == "SVN" | iso_code == "SWE" | iso_code == "TUR" | iso_code == "USA" | iso_code == "ZAF"
ren IndexYear year
drop Name
sort iso_code year 
replace JudicialEffectiveness = "." if JudicialEffectiveness == "N/A"
replace FiscalHealth = "." if FiscalHealth == "N/A"
destring , replace
ren OverallScore EconomicFreedom 
save "${path1}\Bases\Intermediate\Heritage_5.1.21.dta", replace

********************************************************************************
/*                          THE QOG BASIC DATASET                             */
*https://www.gu.se/en/quality-government/qog-data/data-downloads/data-archive
clear all
import excel "${path1}\Bases\Political\qog_bas_ts_jan20.xlsx", sheet("qog_bas_ts_jan20") firstrow
ren ccodealp iso_code
drop if year < 2015
keep if iso_code == "AUS" | iso_code == "AUT" | iso_code == "BEL" | iso_code == "BRA" | iso_code == "CAN" | iso_code == "CHE" | iso_code == "CHL" | iso_code == "CHN" | iso_code == "COL" | iso_code == "CRI" | iso_code == "CZE" | iso_code == "DEU" | iso_code == "DNK" | iso_code == "ESP" | iso_code == "EST" | iso_code == "FIN" | iso_code == "FRA" | iso_code == "GBR" | iso_code == "GRC" | iso_code == "HUN" | iso_code == "IDN" | iso_code == "IND" | iso_code == "IRL" | iso_code == "ISR" | iso_code == "ITA" | iso_code == "JPN" | iso_code == "KOR" | iso_code == "LTU" | iso_code == "LUX" | iso_code == "LVA" | iso_code == "MEX" | iso_code == "NLD" | iso_code == "NOR" | iso_code == "NZL" | iso_code == "POL" | iso_code == "PRT" | iso_code == "RUS" | iso_code == "SVK" | iso_code == "SVN" | iso_code == "SWE" | iso_code == "TUR" | iso_code == "USA" | iso_code == "ZAF"
********************************************************************************
/*                          Geo Pol Risk Index                                */
*https://www.policyuncertainty.com/gpr.html
clear all 
import excel "${path1}\Bases\Political\gpr_web_latest.xlsx", sheet("GPR_COUNTRIES") firstrow clear
drop if missing(year)
drop if missing(month)
reshape long GPR_, i(Date year month)  j(Name) string
ren GPR_ GPR 
keep if Name == "AUSTRALIA" | Name == "AUSTRIA" | Name == "BELGIUM" | Name == "BRAZIL" | Name == "CANADA" | Name == "SWEDEN" | Name == "CHILE" | Name == "CHINA" | Name == "SOUTH_AFRICA" | Name == "ISRAEL" | Name == "TURKEY" | Name == "RUSSIA"| Name == "MEXICO"| Name == "INDIA" | Name == "KOREA" | Name == "INDONESIA"
gen iso_code = "." 
order Name iso_code
replace iso_code = "AUS" if Name == "AUSTRALIA"
replace iso_code = "BRA" if Name == "BRAZIL" 
replace iso_code = "CHL" if Name == "CHILE" 
replace iso_code = "CHN" if Name == "CHINA" 
replace iso_code = "COL" if Name == "COLOMBIA" 
replace iso_code = "IDN" if Name == "INDONESIA" 
replace iso_code = "IND" if Name == "INDIA" 
replace iso_code = "IRL" if Name == "Ireland" 
replace iso_code = "ISR" if Name == "ISRAEL" 
replace iso_code = "KOR" if Name == "KOREA" 
replace iso_code = "MEX" if Name == "MEXICO" 
replace iso_code = "RUS" if Name == "RUSSIA" 
replace iso_code = "TUR" if Name == "TURKEY" 
replace iso_code = "ZAF" if Name == "SOUTH_AFRICA" 
drop Name Date
sort iso_code year month
save "${path1}\Bases\Intermediate\GPR_5.5.21.dta", replace

********************************************************************************
/*                        Political tensions                                  */

*https://www.matteoiacoviello.com/gpr.htm
*https://www.gu.se/en/quality-government/qog-data/data-downloads/data-archive

********************************************************************************

/* Gov Variables : Control of corruption , Gov Effectiveness Pol Stability RuleofLaw */
clear all
import excel "${path1}\Bases\Political\Data_Extract_From_Worldwide_Governance_Indicators.xlsx", sheet("Data") firstrow clear
ren (CountryCode Time GovernmentEffectivenessEstima PoliticalStabilityandAbsence RuleofLawEstimateRLEST ControlofCorruptionEstimate) (iso_code year GovEffect PolStab RuleofLaw ControlofCorr)
drop CountryName TimeCode
drop in 1071/1075
replace GovEffect = "." if GovEffect == ".."
replace PolStab = "." if PolStab == ".."
replace RuleofLaw = "." if RuleofLaw == ".."
replace ControlofCorr = "." if ControlofCorr == ".."
destring , replace
save "${path1}\Bases\Intermediate\WB_GovIndicators_5.3.21.dta", replace
********************************************************************************
/*******************************************************************************
                   Changes for fiscal and monetary variables
*******************************************************************************/
********************************************************************************
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear
*Monetary Policy ir, BIS 
merge m:m iso_code year month using "${path1}\Bases\Intermediate\BIS_ir-3.17.21.dta", nogenerate
sort iso_code year datemdy
*BIS Monetary Policy ir USA, BIS 
merge m:m year month using "${path1}\Bases\Intermediate\BIS_ir_USA-3.20.21.dta", nogenerate
sort iso_code year datemdy

*IMF Monetary Policy ir CRI, BIS 
merge m:m iso_code year month using "${path1}\Bases\Intermediate\ir.IMF-CRI_04-27-21.dta", nogenerate
sort iso_code year datemdy

*Gov Consumption, OECD
merge m:m iso_code year quarter using "${path1}\Bases\Intermediate\OECD_Gov_FinalConsumption_LC-03.18.21.dta", nogenerate
sort iso_code year datemdy
drop LC
*GDP, OECD
merge m:m iso_code year quarter using "${path1}\Bases\Intermediate\OECD_Quarterly_GDP_LC-3.19.21.dta", nogenerate
sort iso_code year datemdy
*Gov Consumption / GDP CHN (not available in OECD) (Only quarter data)
merge m:m iso_code year using "${path1}\Bases\Intermediate\Gov_Final_Cons_GDP_CHN-04.27.21.dta", nogenerate
sort iso_code year datemdy
*Inflation Average, Weo 
merge m:m iso_code year using "${path1}\Bases\Fiscal&Monetary\WEO_Inflation_Average-3.13.21.dta"
sort iso_code year month datemdy 
drop if _merge == 2
drop _merge
*Inflation Average USA, Weo 
merge m:m year using "${path1}\Bases\Intermediate\InflationAverageUSA-3.13.21.dta", nogenerate
sort iso_code year month datemdy 
/*******************************************************************************
Final Consumption LC / Quarterly GDP 
********************************************************************************/
gen Gov_Final_Cons_GDP = FinalConsumption_LC/OECD_Quarterly_GDP_LC

*CHINA only annual available
replace Gov_Final_Cons_GDP = Gov_Final_Cons_GDP_CHN if iso_code == "CHN"

/*******************************************************************************
interest rate IMF for CRI 
********************************************************************************/
replace BIS_ir = ir_IMF_CRI if iso_code == "CRI"

/*******************************************************************************
Real interest rate BIS
********************************************************************************/
gen BIS_real_ir = BIS_ir-Inflation_Average  

/*******************************************************************************
Real interest rate BIS USA
********************************************************************************/
gen BIS_real_ir_USA = BIS_ir_USA-Inflation_Average_USA      

save "${path1}\Bases\Intermediate\FiscalandMonetary_13.4.dta", replace
********************************************************************************
/*******************************************************************************
                         Changes DPI
*******************************************************************************/
********************************************************************************
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear
sort iso_code year datemdy 
merge m:m iso_code year using "${path1}\Bases\Political\DPI2017.dta", keepusing(system execrlc)
drop if year < 2015
drop if missing(quarter)
drop _merge
sort iso_code year datemdy

*Using system 2017 for 2020 / 21
replace system = system[_n-1] if year == 2018
replace system = system[_n-2] if year == 2019
replace system = system[_n-3] if year == 2020
replace system = system[_n-4] if year == 2021
/*
replace execrlc = execrlc[_n-1] if year == 2018
replace execrlc = execrlc[_n-2] if year == 2019
replace execrlc = execrlc[_n-3] if year == 2020
replace execrlc = execrlc[_n-4] if year == 2021
*/
*Australia
replace execrlc = 1 if year == 2016 & iso_code == "AUS" //Malcolm Turnbull
replace execrlc = 1 if year == 2017 & iso_code == "AUS" //Malcolm Turnbull
replace execrlc = 1 if year == 2018 & iso_code == "AUS" //Scott Morrison & Malcolm Turnbull
replace execrlc = 1 if year == 2019 & iso_code == "AUS" //Scott Morrison
replace execrlc = 1 if year == 2020 & iso_code == "AUS" //Scott Morrison
replace execrlc = 1 if year == 2021 & iso_code == "AUS" //Scott Morrison
*Austria
replace execrlc = 3 if year == 2016 & iso_code == "AUT" //Christian Kern
replace execrlc = 3 if year == 2017 & iso_code == "AUT" & month < 12 //Christian Kern
replace execrlc = 1 if year == 2017 & iso_code == "AUT" & month == 12 //Sebastian Kurz
replace execrlc = 1 if year == 2018 & iso_code == "AUT" //Sebastian Kurz
replace execrlc = 1 if year == 2019 & iso_code == "AUT" & month < 6 //  Sebastian Kurz Hartwig Löger
replace execrlc = 0 if year == 2019 & iso_code == "AUT" & month >= 6 //Brigitte Bierlein
replace execrlc = 1 if year == 2020 & iso_code == "AUT" //Sebastian Kurz
replace execrlc = 1 if year == 2021 & iso_code == "AUT" //Sebastian Kurz
*Belgium Yo pondria uno pero esta en 0
replace execrlc = 1 if year == 2016 & iso_code == "BEL" //Charles Michel
replace execrlc = 1 if year == 2017 & iso_code == "BEL" //Charles Michel
replace execrlc = 1 if year == 2018 & iso_code == "BEL" //Charles Michel
replace execrlc = 1 if year == 2019 & iso_code == "BEL" & month < 11 //Charles Michel
replace execrlc = 1 if year == 2019 & iso_code == "BEL" & month >= 11 //Sophie Wilmès
replace execrlc = 1 if year == 2020 & iso_code == "BEL" & month < 10 //Sophie Wilmès
replace execrlc = 1 if year == 2020 & iso_code == "BEL" & month >= 10 //Alexander De Croo
replace execrlc = 1 if year == 2021 & iso_code == "BEL" //Alexander De Croo
*Brazil
replace execrlc = 3 if year == 2016 & iso_code == "BRA" & month < 9
replace execrlc = 2 if year == 2016 & iso_code == "BRA" & month >= 9 //Michel Temer
replace execrlc = 2 if year == 2017 & iso_code == "BRA" //Michel Temer
replace execrlc = 2 if year == 2018 & iso_code == "BRA" //Michel Temer
replace execrlc = 1 if year == 2019 & iso_code == "BRA" //Bolsonaro
replace execrlc = 1 if year == 2020 & iso_code == "BRA" //Bolsonaro
replace execrlc = 1 if year == 2021 & iso_code == "BRA" //Bolsonaro
*Canada
replace execrlc = 3 if year == 2016 & iso_code == "CAN"
replace execrlc = 3 if year == 2017 & iso_code == "CAN"
replace execrlc = 3 if year == 2018 & iso_code == "CAN"
replace execrlc = 3 if year == 2019 & iso_code == "CAN"
replace execrlc = 3 if year == 2020 & iso_code == "CAN"
replace execrlc = 3 if year == 2021 & iso_code == "CAN"
*CHE
replace execrlc = 0 if year == 2016 & iso_code == "CHE"
replace execrlc = 0 if year == 2017 & iso_code == "CHE"
replace execrlc = 0 if year == 2018 & iso_code == "CHE"
replace execrlc = 0 if year == 2019 & iso_code == "CHE"
replace execrlc = 0 if year == 2020 & iso_code == "CHE"
replace execrlc = 0 if year == 2021 & iso_code == "CHE"
*Chile
replace execrlc = 3 if year == 2016 & iso_code == "CHL"
replace execrlc = 3 if year == 2017 & iso_code == "CHL"
replace execrlc = 3 if year == 2018 & iso_code == "CHL" & month < 3
replace execrlc = 1 if year == 2018 & iso_code == "CHL" & month >= 3
replace execrlc = 1 if year == 2019 & iso_code == "CHL"
replace execrlc = 1 if year == 2020 & iso_code == "CHL"
replace execrlc = 1 if year == 2021 & iso_code == "CHL"
*China
replace execrlc = 3 if year == 2016 & iso_code == "CHN" //Li Keqiang
replace execrlc = 3 if year == 2017 & iso_code == "CHN" //Li Keqiang
replace execrlc = 3 if year == 2018 & iso_code == "CHN" //Li Keqiang
replace execrlc = 3 if year == 2019 & iso_code == "CHN" //Li Keqiang
replace execrlc = 3 if year == 2020 & iso_code == "CHN" //Li Keqiang
replace execrlc = 3 if year == 2021 & iso_code == "CHN" //Li Keqiang
*Colombia
replace execrlc = 1 if year == 2016 & iso_code == "COL" //Juan Manuel Santos 
replace execrlc = 1 if year == 2017 & iso_code == "COL" //Juan Manuel Santos 
replace execrlc = 1 if year == 2018 & iso_code == "COL" & month < 7 //Juan Manuel Santos 
replace execrlc = 1 if year == 2018 & iso_code == "COL" & month >= 8 //Iván Duque Márquez
replace execrlc = 1 if year == 2019 & iso_code == "COL" //Iván Duque Márquez
replace execrlc = 1 if year == 2020 & iso_code == "COL" //Iván Duque Márquez
replace execrlc = 1 if year == 2021 & iso_code == "COL" //Iván Duque Márquez
*Costa Rica 
replace execrlc = 3 if year == 2016 & iso_code == "CRI"
replace execrlc = 3 if year == 2017 & iso_code == "CRI" & month < 5    //Carlos Alvarado Quesada
replace execrlc = 3 if year == 2018 & iso_code == "CRI" & month >= 5   //Luis Guillermo Solís
replace execrlc = 3 if year == 2019 & iso_code == "CRI"
replace execrlc = 3 if year == 2020 & iso_code == "CRI"
replace execrlc = 3 if year == 2021 & iso_code == "CRI"

*Czech Republic 
replace execrlc = 3 if year == 2016 & iso_code == "CZE" //Bohuslav Sobotka
replace execrlc = 3 if year == 2017 & iso_code == "CZE" & month < 12 //Bohuslav Sobotka
replace execrlc = 1 if year == 2017 & iso_code == "CZE" & month >= 12 //Andrej Babiš
replace execrlc = 1 if year == 2018 & iso_code == "CZE" //Andrej Babiš
replace execrlc = 1 if year == 2019 & iso_code == "CZE" //Andrej Babiš
replace execrlc = 1 if year == 2020 & iso_code == "CZE" //Andrej Babiš
replace execrlc = 1 if year == 2021 & iso_code == "CZE" //Andrej Babiš
*Deutschland 
replace execrlc = 1 if year == 2016 & iso_code == "DEU" //Angela Merkel
replace execrlc = 1 if year == 2017 & iso_code == "DEU" //Angela Merkel
replace execrlc = 1 if year == 2018 & iso_code == "DEU" //Angela Merkel
replace execrlc = 1 if year == 2019 & iso_code == "DEU" //Angela Merkel
replace execrlc = 1 if year == 2020 & iso_code == "DEU" //Angela Merkel
replace execrlc = 1 if year == 2021 & iso_code == "DEU" //Angela Merkel
*Denmark 
replace execrlc = 1 if year == 2016 & iso_code == "DNK" //Lars Løkke Rasmussen
replace execrlc = 1 if year == 2017 & iso_code == "DNK" //Lars Løkke Rasmussen
replace execrlc = 1 if year == 2018 & iso_code == "DNK" //Lars Løkke Rasmussen
replace execrlc = 1 if year == 2019 & iso_code == "DNK" & month < 7 //Lars Løkke Rasmussen
replace execrlc = 3 if year == 2019 & iso_code == "DNK" & month >= 7 //Mette Frederiksen
replace execrlc = 3 if year == 2020 & iso_code == "DNK" //Mette Frederiksen
replace execrlc = 3 if year == 2021 & iso_code == "DNK" //Mette Frederiksen
*Spain
replace execrlc = 1 if year == 2016 & iso_code == "ESP" //Mariano Rajoy
replace execrlc = 1 if year == 2017 & iso_code == "ESP" //Mariano Rajoy
replace execrlc = 1 if year == 2018 & iso_code == "ESP" & month < 6 //Mariano Rajoy
replace execrlc = 3 if year == 2018 & iso_code == "ESP" & month >= 6 //Pedro Sánchez
replace execrlc = 3 if year == 2019 & iso_code == "ESP" //Pedro Sánchez
replace execrlc = 3 if year == 2020 & iso_code == "ESP" //Pedro Sánchez
replace execrlc = 3 if year == 2021 & iso_code == "ESP" //Pedro Sánchez
*Estonia
replace execrlc = 0 if year == 2017 & iso_code == "EST"
replace execrlc = 0 if year == 2018 & iso_code == "EST" & month < 6
replace execrlc = 0 if year == 2018 & iso_code == "EST" & month >= 6
replace execrlc = 0 if year == 2019 & iso_code == "EST"
replace execrlc = 0 if year == 2020 & iso_code == "EST"
replace execrlc = 1 if year == 2021 & iso_code == "EST" & month >= 2
*Finland
replace execrlc = 2 if year == 2017 & iso_code == "FIN" //Juha Sipilä
replace execrlc = 2 if year == 2018 & iso_code == "FIN" //Juha Sipilä
replace execrlc = 2 if year == 2019 & iso_code == "FIN" & month < 6 //Juha Sipilä
replace execrlc = 3 if year == 2019 & iso_code == "FIN" & month >= 6 //Antti Rinne & Sanna Marin
replace execrlc = 3 if year == 2020 & iso_code == "FIN" //Sanna Marin
replace execrlc = 3 if year == 2021 & iso_code == "FIN" //Sanna Marin
*France
replace execrlc = 3 if year == 2016 & iso_code == "FRA" //François Hollande
replace execrlc = 3 if year == 2017 & iso_code == "FRA" & month < 5 //François Hollande
replace execrlc = 2 if year == 2017 & iso_code == "FRA" & month >= 5 //Emmanuel Macron
replace execrlc = 2 if year == 2018 & iso_code == "FRA" //Emmanuel Macron
replace execrlc = 2 if year == 2019 & iso_code == "FRA" //Emmanuel Macron
replace execrlc = 2 if year == 2020 & iso_code == "FRA" //Emmanuel Macron
replace execrlc = 2 if year == 2021 & iso_code == "FRA" //Emmanuel Macron
*GBR
replace execrlc = 1 if year == 2016 & iso_code == "GBR" & month < 7 //David Cameron
replace execrlc = 1 if year == 2016 & iso_code == "GBR" & month >= 7 //Theresa May
replace execrlc = 1 if year == 2017 & iso_code == "GBR" //Theresa May
replace execrlc = 1 if year == 2018 & iso_code == "GBR" //Theresa May
replace execrlc = 1 if year == 2019 & iso_code == "GBR" & month < 8 //Theresa May
replace execrlc = 1 if year == 2019 & iso_code == "GBR" & month > =8 //Boris Johnson
replace execrlc = 1 if year == 2020 & iso_code == "GBR" //Boris Johnson
replace execrlc = 1 if year == 2021 & iso_code == "GBR" //Boris Johnson
*Greece
replace execrlc = 3 if year == 2016 & iso_code == "GRC" //Alexis Tsipras 
replace execrlc = 3 if year == 2017 & iso_code == "GRC" //Alexis Tsipras
replace execrlc = 3 if year == 2018 & iso_code == "GRC" //Alexis Tsipras
replace execrlc = 3 if year == 2019 & iso_code == "GRC" & month < 7 //Alexis Tsipras
replace execrlc = 1 if year == 2019 & iso_code == "GRC" & month >= 7 //Kyriakos Mitsotakis
replace execrlc = 1 if year == 2020 & iso_code == "GRC" //Kyriakos Mitsotakis
replace execrlc = 1 if year == 2021 & iso_code == "GRC" //Kyriakos Mitsotakis
*Hungary 
replace execrlc = 1 if year == 2016 & iso_code == "HUN" //Viktor Orbán                      
replace execrlc = 1 if year == 2017 & iso_code == "HUN" //Viktor Orbán                      
replace execrlc = 1 if year == 2018 & iso_code == "HUN" //Viktor Orbán                      
replace execrlc = 1 if year == 2019 & iso_code == "HUN" //Viktor Orbán                     
replace execrlc = 1 if year == 2020 & iso_code == "HUN" //Viktor Orbán                     
replace execrlc = 1 if year == 2021 & iso_code == "HUN" //Viktor Orbán                      
*Indonesia  
replace execrlc = 3 if year == 2016 & iso_code == "IDN" //Joko Widodo                          
replace execrlc = 3 if year == 2017 & iso_code == "IDN" //Joko Widodo
replace execrlc = 3 if year == 2018 & iso_code == "IDN" //Joko Widodo 
replace execrlc = 3 if year == 2019 & iso_code == "IDN" //Joko Widodo
replace execrlc = 3 if year == 2020 & iso_code == "IDN" //Joko Widodo
replace execrlc = 3 if year == 2021 & iso_code == "IDN" //Joko Widodo
*India  
replace execrlc = 1 if year == 2016 & iso_code == "IND" //Narendra Modi                 
replace execrlc = 1 if year == 2017 & iso_code == "IND" //Narendra Modi
replace execrlc = 1 if year == 2018 & iso_code == "IND" //Narendra Modi
replace execrlc = 1 if year == 2019 & iso_code == "IND" //Narendra Modi
replace execrlc = 1 if year == 2020 & iso_code == "IND" //Narendra Modi
replace execrlc = 1 if year == 2021 & iso_code == "IND" //Narendra Modi
*Ireland
replace execrlc = 1 if year == 2015 & iso_code == "IRL" //Leo Varadkar
replace execrlc = 1 if year == 2016 & iso_code == "IRL" //Leo Varadkar
replace execrlc = 1 if year == 2017 & iso_code == "IRL" //Leo Varadkar
replace execrlc = 1 if year == 2018 & iso_code == "IRL" //Leo Varadkar
replace execrlc = 1 if year == 2019 & iso_code == "IRL" //Leo Varadkar
replace execrlc = 1 if year == 2020 & iso_code == "IRL" & month < 7 //Leo Varadkar
replace execrlc = 2 if year == 2020 & iso_code == "IRL" & month >= 7 //Micheál Martin
replace execrlc = 2 if year == 2021 & iso_code == "IRL" //Micheál Martin coalicion
*Israel 
replace execrlc = 1 if year == 2015 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2016 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2017 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2018 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2019 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2020 & iso_code == "ISR" //Benjamín Netanyahu
replace execrlc = 1 if year == 2021 & iso_code == "ISR" //Benjamín Netanyahu
*Italy no estoy seguro 
replace execrlc = 0 if year == 2015 & iso_code == "ITA" //
replace execrlc = 0 if year == 2016 & iso_code == "ITA" //
replace execrlc = 0 if year == 2017 & iso_code == "ITA" //
replace execrlc = 0 if year == 2018 & iso_code == "ITA" //
replace execrlc = 0 if year == 2019 & iso_code == "ITA" //
replace execrlc = 0 if year == 2020 & iso_code == "ITA" //
replace execrlc = 0 if year == 2021 & iso_code == "ITA" //
*Japan
replace execrlc = 1 if year == 2016 & iso_code == "JPN" //Shinzō Abe
replace execrlc = 1 if year == 2017 & iso_code == "JPN" //Shinzō Abe
replace execrlc = 1 if year == 2018 & iso_code == "JPN" //Shinzō Abe
replace execrlc = 1 if year == 2019 & iso_code == "JPN" //Shinzō Abe
replace execrlc = 1 if year == 2020 & iso_code == "JPN" //Shinzō Abe & Yoshihide Suga
replace execrlc = 1 if year == 2021 & iso_code == "JPN" //Yoshihide Suga
*South Korea
replace execrlc = 1 if year == 2016 & iso_code == "KOR" 
replace execrlc = 1 if year == 2017 & iso_code == "KOR" & month < 5
replace execrlc = 3 if year == 2017 & iso_code == "KOR" & month >= 5
replace execrlc = 3 if year == 2018 & iso_code == "KOR"
replace execrlc = 3 if year == 2019 & iso_code == "KOR"
replace execrlc = 3 if year == 2020 & iso_code == "KOR"
replace execrlc = 3 if year == 2021 & iso_code == "KOR"
*Lithuania
replace execrlc = 0 if year == 2017 & iso_code == "LTU" //1?Saulius Skvernelis
replace execrlc = 0 if year == 2018 & iso_code == "LTU" //1?Saulius Skvernelis
replace execrlc = 0 if year == 2019 & iso_code == "LTU" //1?Saulius Skvernelis
replace execrlc = 0 if year == 2020 & iso_code == "LTU" & month < 12 //1?Saulius Skvernelis
replace execrlc = 1 if year == 2020 & iso_code == "LTU" & month == 12 //Ingrida Šimonytė
replace execrlc = 1 if year == 2021 & iso_code == "LTU" //Ingrida Šimonytė
*Luxemburg
replace execrlc = 2 if year == 2017 & iso_code == "LUX" //Xavier Bettel
replace execrlc = 2 if year == 2018 & iso_code == "LUX" //Xavier Bettel
replace execrlc = 2 if year == 2019 & iso_code == "LUX" //Xavier Bettel
replace execrlc = 2 if year == 2019 & iso_code == "LUX" //Xavier Bettel
replace execrlc = 2 if year == 2020 & iso_code == "LUX" //Xavier Bettel
replace execrlc = 2 if year == 2021 & iso_code == "LUX" //Xavier Bettel
*Latvia
replace execrlc = 1 if year == 2017 & iso_code == "LVA" //Māris Kučinskis
replace execrlc = 1 if year == 2018 & iso_code == "LVA" //Māris Kučinskis
replace execrlc = 1 if year == 2019 & iso_code == "LVA" & month == 1 //Māris Kučinskis
replace execrlc = 1 if year == 2019 & iso_code == "LVA" & month > 1 //Krišjānis Kariņš
replace execrlc = 1 if year == 2020 & iso_code == "LVA" //Krišjānis Kariņš
replace execrlc = 1 if year == 2021 & iso_code == "LVA" //Krišjānis Kariņš
*AMLO Since december 2018
replace execrlc = 2 if year == 2016 & iso_code == "MEX" //Peña Nieto
replace execrlc = 2 if year == 2017 & iso_code == "MEX" //Peña Nieto
replace execrlc = 2 if year == 2018 & iso_code == "MEX" & month < 12 //Peña Nieto
replace execrlc = 3 if year == 2018 & iso_code == "MEX" & month == 12 //AMLO
replace execrlc = 3 if year == 2019 & iso_code == "MEX" //AMLO
replace execrlc = 3 if year == 2020 & iso_code == "MEX" //AMLO
replace execrlc = 3 if year == 2021 & iso_code == "MEX"  //AMLO
*Netherlands
replace execrlc = 1 if year == 2016 & iso_code == "NLD" //Mark Rutte
replace execrlc = 1 if year == 2017 & iso_code == "NLD" //Mark Rutte
replace execrlc = 1 if year == 2018 & iso_code == "NLD" //Mark Rutte
replace execrlc = 1 if year == 2019 & iso_code == "NLD" //Mark Rutte
replace execrlc = 1 if year == 2020 & iso_code == "NLD" //Mark Rutte
replace execrlc = 1 if year == 2021 & iso_code == "NLD" //Mark Rutte
*Norway
replace execrlc = 1 if year == 2016 & iso_code == "NOR" //Erna Solberg
replace execrlc = 1 if year == 2017 & iso_code == "NOR" //Erna Solberg 
replace execrlc = 1 if year == 2018 & iso_code == "NOR" //Erna Solberg 
replace execrlc = 1 if year == 2019 & iso_code == "NOR" //Erna Solberg 
replace execrlc = 1 if year == 2020 & iso_code == "NOR" //Erna Solberg 
replace execrlc = 1 if year == 2021 & iso_code == "NOR" //Erna Solberg 
*New Zeland
replace execrlc = 1 if year == 2017 & iso_code == "NZL" & month < 11 //Bill English
replace execrlc = 3 if year == 2017 & iso_code == "NZL" & month >= 11 //Jacinda Ardern
replace execrlc = 3 if year == 2018 & iso_code == "NZL" //Jacinda Ardern
replace execrlc = 3 if year == 2019 & iso_code == "NZL" //Jacinda Ardern
replace execrlc = 3 if year == 2020 & iso_code == "NZL" //Jacinda Ardern
replace execrlc = 3 if year == 2021 & iso_code == "NZL" //Jacinda Ardern
*Polonia
replace execrlc = 1 if year == 2016 & iso_code == "POL" //Andrzej Duda
replace execrlc = 1 if year == 2017 & iso_code == "POL" //Andrzej Duda
replace execrlc = 1 if year == 2018 & iso_code == "POL" //Andrzej Duda
replace execrlc = 1 if year == 2019 & iso_code == "POL" //Andrzej Duda
replace execrlc = 1 if year == 2020 & iso_code == "POL" //Andrzej Duda
replace execrlc = 1 if year == 2021 & iso_code == "POL" //Andrzej Duda
*Portugal
replace execrlc = 0 if year == 2016 & iso_code == "PRT" 
replace execrlc = 0 if year == 2017 & iso_code == "PRT" 
replace execrlc = 0 if year == 2018 & iso_code == "PRT" 
replace execrlc = 0 if year == 2019 & iso_code == "PRT" 
replace execrlc = 0 if year == 2020 & iso_code == "PRT" 
replace execrlc = 0 if year == 2021 & iso_code == "PRT" 
*Rus
replace execrlc = 3 if year == 2017 & iso_code == "RUS" //VER
replace execrlc = 3 if year == 2018 & iso_code == "RUS" //VER 
replace execrlc = 3 if year == 2018 & iso_code == "RUS" //VER 
replace execrlc = 3 if year == 2019 & iso_code == "RUS" //VER 
replace execrlc = 3 if year == 2020 & iso_code == "RUS" //VER 
replace execrlc = 3 if year == 2021 & iso_code == "RUS" //VER 
*Slovakia 
replace execrlc = 3 if year == 2017 & iso_code == "SVK" & month < 4 //Robert Fico
replace execrlc = 3 if year == 2018 & iso_code == "SVK" & month < 4 //Robert Fico
replace execrlc = 3 if year == 2018 & iso_code == "SVK" & month >= 4 //Peter Pellegrini
replace execrlc = 3 if year == 2019 & iso_code == "SVK" //Peter Pellegrini
replace execrlc = 3 if year == 2020 & iso_code == "SVK" & month < 4 //Peter Pellegrini
replace execrlc = 1 if year == 2020 & iso_code == "SVK" & month >= 4 //Igor Matovič
replace execrlc = 1 if year == 2021 & iso_code == "SVK" //Igor Matovič
*Slovenia        *VER 
replace execrlc = 0 if year == 2017 & iso_code == "SVN" 
replace execrlc = 0 if year == 2018 & iso_code == "SVN" & month < 9
replace execrlc = 0 if year == 2018 & iso_code == "SVN" & month >=9
replace execrlc = 0 if year == 2019 & iso_code == "SVN"
replace execrlc = 0 if year == 2020 & iso_code == "SVN" & month < 3 //Marjan Šarec
replace execrlc = 1 if year == 2020 & iso_code == "SVN" & month >= 3 //Janez Janša
replace execrlc = 1 if year == 2021 & iso_code == "SVN" //Janez Janša
*Sweden
replace execrlc = 3 if year == 2015 & iso_code == "SWE" //Stefan Löfven
replace execrlc = 3 if year == 2016 & iso_code == "SWE" //Stefan Löfven
replace execrlc = 3 if year == 2017 & iso_code == "SWE" //Stefan Löfven
replace execrlc = 3 if year == 2018 & iso_code == "SWE" //Stefan Löfven
replace execrlc = 3 if year == 2019 & iso_code == "SWE" //Stefan Löfven
replace execrlc = 3 if year == 2020 & iso_code == "SWE" //Stefan Löfven
*Turkey
replace execrlc = 1 if year == 2015 & iso_code == "TUR" //Recep Tayyip Erdoğan
replace execrlc = 1 if year == 2016 & iso_code == "TUR" //Recep Tayyip Erdoğan
replace execrlc = 1 if year == 2017 & iso_code == "TUR" //Recep Tayyip Erdoğan
replace execrlc = 1 if year == 2018 & iso_code == "TUR" //Recep Tayyip Erdoğan
replace execrlc = 1 if year == 2019 & iso_code == "TUR" //Recep Tayyip Erdoğan
replace execrlc = 1 if year == 2020 & iso_code == "TUR" //Recep Tayyip Erdoğan
*USA
replace execrlc = 3 if year == 2016 & iso_code == "USA" //Obama     
replace execrlc = 3 if year == 2017 & iso_code == "USA" & month == 1 //Obama                  
replace execrlc = 1 if year == 2017 & iso_code == "USA" & month > 1 //Trump
replace execrlc = 1 if year == 2018 & iso_code == "USA" //Trump
replace execrlc = 1 if year == 2019 & iso_code == "USA" //Trump
replace execrlc = 1 if year == 2020 & iso_code == "USA" //Trump
replace execrlc = 1 if year == 2021 & iso_code == "USA" & month == 1 //Trump
replace execrlc = 3 if year == 2021 & iso_code == "USA" & month > 1 //Biden
*ZAF                       
replace execrlc = 3 if year == 2017 & iso_code == "ZAF"
replace execrlc = 3 if year == 2018 & iso_code == "ZAF" 
replace execrlc = 3 if year == 2019 & iso_code == "ZAF"
replace execrlc = 3 if year == 2020 & iso_code == "ZAF"
replace execrlc = 3 if year == 2021 & iso_code == "ZAF" 
*Set missing as . and No info for execrlc as missing .
replace execrlc = . if execrlc == -999
replace system = . if system == -999
save "${path1}\Bases\Intermediate\DPI_13.4.dta", replace

********************************************************************************
/*******************************************************************************
                         Changes Tracker
*******************************************************************************/
********************************************************************************
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\OxCGRT_latest-2.24.21.dta"
drop if quarter == .
sort iso_code year datemdy 
********************************************************************************
* 0s before first obs 
* C ****************************************************************************
*New Names
rename c1_schoolclosing C1_Schoolclosing
rename c2_workplaceclosing C2_Workplaceclosing
rename c3_cancelpublicevents C3_Cancelpublicevents
rename c4_restrictionsongatherings C4_Restrictionsongatherings
rename c5_closepublictransport C5_Closepublictransport
rename c6_stayathomerequirements C6_Stayathomerequirements
rename c7_restrictionsoninternalmovemen C7_Restrictionsoninternalmove
rename c8_internationaltravelcontrols C8_Internationaltravelcontrols
rename c1_flag C1_Flag
rename c2_flag C2_Flag
rename c3_flag C3_Flag
rename c4_flag C4_Flag
rename c5_flag C5_Flag
rename c6_flag C6_Flag
rename c7_flag C7_Flag
by iso_code, sort: egen FirstTimeC1 = min(cond(C1_Schoolclosing != ., datemdy, .))
replace C1_Schoolclosing = 0 if FirstTimeC1 > datemdy &  FirstTimeC1 != .
*drop FirstTimeC1
by iso_code, sort: egen FirstTimeC2 = min(cond(C2_Workplaceclosing != ., datemdy, .))
replace C2_Workplaceclosing = 0 if FirstTimeC2 > datemdy &  FirstTimeC2 != .
*drop FirstTimeC2
by iso_code, sort: egen FirstTimeC3 = min(cond(C3_Cancelpublicevents != ., datemdy, .))
replace C3_Cancelpublicevents = 0 if FirstTimeC3 > datemdy &  FirstTimeC3 != .
*drop FirstTimeC3
by iso_code, sort: egen FirstTimeC4 = min(cond(C4_Restrictionsongatherings != ., datemdy, .))
replace C4_Restrictionsongatherings = 0 if FirstTimeC4 > datemdy &  FirstTimeC4 != .
*drop FirstTimeC4
by iso_code, sort: egen FirstTimeC5 = min(cond(C5_Closepublictransport != ., datemdy, .))
replace C5_Closepublictransport = 0 if FirstTimeC5 > datemdy &  FirstTimeC5 != .
*drop FirstTimeC5
by iso_code, sort: egen FirstTimeC6 = min(cond(C6_Stayathomerequirements != ., datemdy, .))
replace C6_Stayathomerequirements = 0 if FirstTimeC6 > datemdy &  FirstTimeC6 != .
*drop FirstTimeC6
by iso_code, sort: egen FirstTimeC7 = min(cond(C7_Restrictionsoninternalmove != ., datemdy, .))
replace C7_Restrictionsoninternalmove = 0 if FirstTimeC7 > datemdy &  FirstTimeC7 != .
*drop FirstTimeC7
by iso_code, sort: egen FirstTimeC8 = min(cond(C8_Internationaltravelcontrols != ., datemdy, .))
replace C8_Internationaltravelcontrols = 0 if FirstTimeC8 > datemdy &  FirstTimeC8 != .
*drop FirstTimeC8

* E ****************************************************************************
*Remplazo por viejos nombres, nuevos nombres del Oxford Trucker (Difiere mayus)
rename e1_incomesupport E1_Incomesupport
rename e2_debtcontractrelief E2_Debtcontractrelief
rename e3_fiscalmeasures E3_Fiscalmeasures
rename e4_internationalsupport E4_Internationalsupport
rename e1_flag E1_Flag
by iso_code, sort: egen FirstTimeE1 = min(cond(E1_Incomesupport != ., datemdy, .))
replace E1_Incomesupport = 0 if FirstTimeE1 > datemdy & FirstTimeE1 != .
*drop FirstTimeE1
by iso_code, sort: egen FirstTimeE2 = min(cond(E2_Debtcontractrelief != ., datemdy, .))
replace E2_Debtcontractrelief = 0 if FirstTimeE2 > datemdy & FirstTimeE2 != .
*drop FirstTimeE2
by iso_code, sort: egen FirstTimeE3 = min(cond(E3_Fiscalmeasures != ., datemdy, .))
replace E3_Fiscalmeasures = 0 if FirstTimeE3 > datemdy & FirstTimeE3 != .
*drop FirstTimeE3
by iso_code, sort: egen FirstTimeE4 = min(cond(E4_Internationalsupport != ., datemdy, .))
replace E4_Internationalsupport = 0 if FirstTimeE4 > datemdy & FirstTimeE4 != .
*drop FirstTimeE4
* H ****************************************************************************
*Remplazo por viejos nombres, nuevos nombres del Oxford Trucker (Difiere mayus)
rename h1_publicinformationcampaigns H1_Publicinformationcampaigns
rename h2_testingpolicy H2_Testingpolicy
rename h3_contacttracing H3_Contacttracing
rename h4_emergencyinvestmentinhealthca H4_Emergencyinvestmentinhealt
rename h5_investmentinvaccines H5_Investmentinvaccines
rename h6_facialcoverings H6_FacialCoverings
rename h7_vaccinationpolicy H7_Vaccinationpolicy
rename h1_flag H1_Flag
rename h6_flag H6_Flag
rename h7_flag H7_Flag
by iso_code, sort: egen FirstTimeH1 = min(cond(H1_Publicinformationcampaigns != ., datemdy, .))
replace H1_Publicinformationcampaigns = 0 if FirstTimeH1 > datemdy & FirstTimeH1!= .
*drop FirstTimeH1
by iso_code, sort: egen FirstTimeH2 = min(cond(H2_Testingpolicy != ., datemdy, .))
replace H2_Testingpolicy = 0 if FirstTimeH2 > datemdy & FirstTimeH2 != .
*drop FirstTimeH2
by iso_code, sort: egen FirstTimeH3 = min(cond(H3_Contacttracing != ., datemdy, .))
replace H3_Contacttracing = 0 if FirstTimeH3 > datemdy & FirstTimeH3 != .
*drop FirstTimeH3
by iso_code, sort: egen FirstTimeH4 = min(cond(H4_Emergencyinvestmentinhealt != ., datemdy, .))
replace H4_Emergencyinvestmentinhealt = 0 if FirstTimeH4 > datemdy & FirstTimeH4 != .
*drop FirstTimeH4
by iso_code, sort: egen FirstTimeH5 = min(cond(H5_Investmentinvaccines != ., datemdy, .))
replace H5_Investmentinvaccines = 0 if FirstTimeH5 > datemdy & FirstTimeH5 != .
*drop FirstTimeH5
by iso_code, sort: egen FirstTimeH6 = min(cond(H6_FacialCoverings!= ., datemdy, .))
replace H6_FacialCoverings = 0 if FirstTimeH6 > datemdy & FirstTimeH6 != .
*drop FirstTimeH6
by iso_code, sort: egen FirstTimeH7 = min(cond(H7_Vaccinationpolicy!= ., datemdy, .))
replace H7_Vaccinationpolicy = 0 if FirstTimeH7 > datemdy & FirstTimeH7 != .
*drop FirstTimeH7
*   Construcción de variables binarias
* C ****************************************************************************
*Generación de variables
g C1_binary = .
g C2_binary = .
g C3_binary = .
g C4_binary = .
g C5_binary = .
g C6_binary = .
g C7_binary = .
g C8_binary = .
*Valores
replace C1_binary = 1 if C1_Schoolclosing == 1|C1_Schoolclosing == 2|C1_Schoolclosing == 3
replace C2_binary = 1 if C2_Workplaceclosing == 1|C2_Workplaceclosing == 2|C2_Workplaceclosing == 3
replace C3_binary = 1 if C3_Cancelpublicevents == 1 | C3_Cancelpublicevents == 2
replace C4_binary = 1 if C4_Restrictionsongatherings == 1|C4_Restrictionsongatherings == 2|C4_Restrictionsongatherings == 3|C4_Restrictionsongatherings == 4
replace C5_binary = 1 if C5_Closepublictransport == 1|C5_Closepublictransport == 2
replace C6_binary = 1 if C6_Stayathomerequirements == 1|C6_Stayathomerequirements == 2|C6_Stayathomerequirements == 3
replace C7_binary = 1 if C7_Restrictionsoninternalmove == 1|C7_Restrictionsoninternalmove == 2
replace C8_binary = 1 if C8_Internationaltravelcontrols == 1|C8_Internationaltravelcontrols == 2|C8_Internationaltravelcontrols == 3|C8_Internationaltravelcontrols == 4
*Remplazo con 0
replace C1_binary = 0 if C1_Schoolclosing == 0
replace C2_binary = 0 if C2_Workplaceclosing == 0
replace C3_binary = 0 if C3_Cancelpublicevents == 0 
replace C4_binary = 0 if C4_Restrictionsongatherings == 0
replace C5_binary = 0 if C5_Closepublictransport == 0
replace C6_binary = 0 if C6_Stayathomerequirements == 0
g C6_Stayathomerequirements_binary = .
replace C6_Stayathomerequirements_binary = 1 if C6_Stayathomerequirements == 1|C6_Stayathomerequirements == 2|C6_Stayathomerequirements == 3
replace C6_Stayathomerequirements_binary = 0 if C6_Stayathomerequirements == 0
replace C7_binary = 0 if C7_Restrictionsoninternalmove == 0
replace C8_binary = 0 if C8_Internationaltravelcontrols == 0
* E ****************************************************************************
*Generación de variables
g E1_binary = .
g E2_binary = .
*Valores
replace E1_binary = 1 if E1_Incomesupport == 1|E1_Incomesupport == 2
replace E2_binary = 1 if E2_Debtcontractrelief == 1|E2_Debtcontractrelief == 2
*Remplazo con 0
replace E1_binary = 0 if E1_Incomesupport == 0
replace E2_binary = 0 if E2_Debtcontractrelief == 0
*Resto 3 y 4 en usd
* H ****************************************************************************
*Generación de variables
g H1_binary = .
g H2_binary = .
g H3_binary = .
g H6_binary = .
g H7_binary = .
*Valores
replace H1_binary = 1 if H1_Publicinformationcampaigns == 1|H1_Publicinformationcampaigns == 2
replace H2_binary = 1 if H2_Testingpolicy == 1|H2_Testingpolicy == 2|H2_Testingpolicy == 3
replace H3_binary = 1 if H3_Contacttracing == 1|H3_Contacttracing == 2
replace H6_binary = 1 if H6_FacialCoverings == 1|H6_FacialCoverings == 2|H6_FacialCoverings == 3|H6_FacialCoverings == 4
replace H7_binary = 1 if H7_Vaccinationpolicy == 1|H7_Vaccinationpolicy == 2|H7_Vaccinationpolicy == 3|H7_Vaccinationpolicy == 4|H7_Vaccinationpolicy == 5
*Remplazo con 0 
replace H1_binary = 0 if H1_Publicinformationcampaigns == 0
replace H2_binary = 0 if H2_Testingpolicy == 0
replace H3_binary = 0 if H3_Contacttracing == 0
replace H6_binary = 0 if H6_FacialCoverings == 0
replace H7_binary = 0 if H7_Vaccinationpolicy == 0
*Resto 4 y 5 en usd
* INDICES **********************************************************************
*Remplazo por viejos nombres, nuevos nombres del Oxford Trucker (Difiere mayus)
rename stringencyindex StringencyIndex
rename stringencyindexfordisplay StringencyIndexForDisplay
rename stringencylegacyindex StringencyLegacyIndex
rename stringencylegacyindexfordisplay StringencyLegacyIndexForDisplay
rename governmentresponseindex GovernmentResponseIndex
rename governmentresponseindexfordispla GovernmentresponseindexForDispla
rename containmenthealthindex ContainmentHealthIndex
rename containmenthealthindexfordisplay ContainmentHealthIndexForDisplay
rename economicsupportindex EconomicSupportIndex
rename economicsupportindexfordisplay EconomicSupportIndexForDisplay
*Remplazo con 0 información anterior a primer observación (.)
*
by iso_code, sort: egen FirstTimeSI = min(cond(StringencyIndex != . , datemdy, .))
format FirstTimeSI %d
replace StringencyIndex = 0 if FirstTimeSI > datemdy &  FirstTimeSI != .
*
by iso_code, sort: egen FirstTimeSLI= min(cond(StringencyLegacyIndex != . , datemdy, .))
format FirstTimeSLI %d
replace StringencyLegacyIndex = 0 if FirstTimeSLI > datemdy &  FirstTimeSLI != .
*drop FirstTimeSLI
*
by iso_code, sort: egen FirstTimeGRI= min(cond(GovernmentResponseIndex != . , datemdy, .))
format FirstTimeGRI %d
replace GovernmentResponseIndex= 0 if FirstTimeGRI > datemdy &  FirstTimeGRI != .
drop FirstTimeGRI
*
by iso_code, sort: egen FirstTimeCHI= min(cond(ContainmentHealthIndex != . , datemdy, .))
format FirstTimeCHI %d
replace ContainmentHealthIndex = 0 if FirstTimeCHI > datemdy &  FirstTimeCHI != .
drop FirstTimeCHI
*
by iso_code, sort: egen FirstTimeESI= min(cond(EconomicSupportIndex != . , datemdy, .))
format FirstTimeESI %d
replace EconomicSupportIndex = 0 if FirstTimeESI > datemdy &  FirstTimeESI != .
*drop FirstTimeESI

*   Construcción de Indices
* E Prueba
g IE1 = .
replace IE1 = 100*[E1_Incomesupport-0.5*(1-E1_Flag)]/2 if E1_Flag != . & E1_Incomesupport != .
replace IE1 = 100*[E1_Incomesupport]/2 if E1_Flag == . & E1_Incomesupport != .
replace IE1 = 0 if E1_Incomesupport == . & FirstTimeE1 != .
g IE2 = .
replace IE2 = 100*[E2_Debtcontractrelief]/2 if E2_Debtcontractrelief != .
replace IE2 = 0 if E2_Debtcontractrelief == . & FirstTimeE2 != .
g IE = 1/2*[ IE1 + IE2] /*Igual indice economico, pruebo formula*/

by iso_code, sort: egen FirstTimeIE = min(cond(IE != . , datemdy, .))
format FirstTimeIE %d
replace IE = 0 if FirstTimeIE > datemdy & FirstTimeIE != .
*drop FirstTimeIE
drop FirstTimeE3
by iso_code, sort: egen FirstTimeE3 = min(cond(E3_Fiscalmeasures != . , datemdy, .))
format FirstTimeE3 %d
replace E3_Fiscalmeasures = 0 if FirstTimeE3 > datemdy & FirstTimeE3 != .
egen std_E3=  std(E3_Fiscalmeasures)
****************
g IC1 = .
replace IC1 = 100*[C1_Schoolclosing-0.5*(1-C1_Flag)]/3 if C1_Flag != . & C1_Schoolclosing != .
replace IC1 = 100*[C1_Schoolclosing]/3 if C1_Flag == . & C1_Schoolclosing != .
replace IC1 = 0 if C1_Flag == . & C1_Schoolclosing == . & FirstTimeC1 != .
g IC2 = .
replace IC2 = 100*[C2_Workplaceclosing-0.5*(1-C2_Flag)]/3 if C2_Flag != . & C2_Workplaceclosing != .
replace IC2 = 100*[C2_Workplaceclosing]/3 if C2_Flag == . & C2_Workplaceclosing != . 
replace IC2 = 0 if C2_Flag == . & C2_Workplaceclosing == . & FirstTimeC2 != .
g IC3 = .
replace IC3 = 100*[C3_Cancelpublicevents-0.5*(1-C3_Flag)]/2 if C3_Flag != . & C3_Cancelpublicevents != .
replace IC3 = 100*[C3_Cancelpublicevents]/2 if C3_Flag == . & C3_Cancelpublicevents != . 
replace IC3 = 0 if C3_Flag == . & C3_Cancelpublicevents == . & FirstTimeC3 != .
g IC4 = .
replace IC4 = 100*[C4_Restrictionsongatherings-0.5*(1-C4_Flag)]/4 if C4_Flag != . & C4_Restrictionsongatherings != . 
replace IC4 = 100*[C4_Restrictionsongatherings]/4 if C4_Flag == . & C4_Restrictionsongatherings != . 
replace IC4 = 0 if C4_Flag == . & C4_Restrictionsongatherings == . & FirstTimeC4 != .
g IC5 = .
replace IC5 = 100*[C5_Closepublictransport-0.5*(1-C5_Flag)]/2 if C5_Flag != . & C5_Closepublictransport != . 
replace IC5 = 100*[C5_Closepublictransport]/2 if C5_Flag == . & C5_Closepublictransport != . 
replace IC5 = 0 if C5_Flag == . & C5_Closepublictransport == .  & FirstTimeC5 != .
g IC6 = .
replace IC6 = 100*[C6_Stayathomerequirements-0.5*(1-C6_Flag)]/3 if C6_Flag != . & C6_Stayathomerequirements != . 
replace IC6 = 100*[C6_Stayathomerequirements]/3 if C6_Flag == . & C6_Stayathomerequirements != . 
replace IC6 = 0 if C6_Flag == . & C6_Stayathomerequirements == .  & FirstTimeC6 != .
g IC7 = .
replace IC7 = 100*[C7_Restrictionsoninternalmove-0.5*(1-C7_Flag)]/2 if C7_Flag != . & C7_Restrictionsoninternalmove != . 
replace IC7 = 100*[C7_Restrictionsoninternalmove]/2 if C7_Flag == . & C7_Restrictionsoninternalmove != . 
replace IC7 = 0 if C7_Flag == . & C7_Restrictionsoninternalmove == .  & FirstTimeC7 != .
g IC8 = .
replace IC8 = 100*[C8_Internationaltravelcontrols]/4
replace IC8 = 0 if C8_Internationaltravelcontrols == . & FirstTimeC8 != .
g IH1 = .
replace IH1  = 100*[H1_Publicinformationcampaigns-0.5*(1-H1_Flag)]/2 if H1_Flag != . & H1_Publicinformationcampaigns != . 
replace IH1  = 100*[H1_Publicinformationcampaigns]/2 if H1_Flag == . & H1_Publicinformationcampaigns != . 
replace IH1  = 0 if H1_Flag == . & H1_Publicinformationcampaigns == . & FirstTimeH1 != . 
g IH2 = .
replace IH2  = 100*[H2_Testingpolicy]/3
replace IH2  = 0 if H2_Testingpolicy == . & FirstTimeH2 != . 
g IH3 = .
replace IH3  = 100*[H3_Contacttracing]/2
replace IH3  = 0 if H3_Contacttracing == . & FirstTimeH3 != . 
g IH6 = .
replace IH6  = 100*[H6_FacialCoverings-0.5*(1-H6_Flag)]/4 if H6_Flag != . & H6_FacialCoverings != . 
replace IH6  = 100*[H6_FacialCoverings]/4 if H6_Flag == . & H6_FacialCoverings != . 
replace IH6  = 0 if H6_Flag == . & H6_FacialCoverings == . & FirstTimeH6 != . 
g IH7 = .
replace IH7  = 100*[H7_Vaccinationpolicy-0.5*(1-H7_Flag)]/4 if H7_Flag != . & H7_Vaccinationpolicy != . 
replace IH7  = 100*[H7_Vaccinationpolicy]/4 if H7_Flag == . & H7_Vaccinationpolicy != . 
replace IH7  = 0 if H7_Flag == . & H7_Vaccinationpolicy == . & FirstTimeH7 != . 
g IS =  1/9*( IC1 + IC2 + IC3 + IC4 + IC5 + IC6 + IC7 + IC8 + IH1)/*Igual a SI*/
*Remplazo por 0 antes de primer dato
by iso_code, sort: egen FirstTimeIS = min(cond(IS != . , datemdy, .))
format FirstTimeIS %d
replace IS = 0 if FirstTimeIS > datemdy & FirstTimeIS != .
*drop FirstTimeIS
*Indice C, Restricciones
g IC = 1/8*( IC1 + IC2 + IC3 + IC4 + IC5 + IC6 + IC7 + IC8) 
by iso_code, sort: egen FirstTimeIC = min(cond(IC != . , datemdy, .))
format FirstTimeIC %d
replace IC = 0 if FirstTimeIC > datemdy & FirstTimeIC != .
*Indice H, Salud
g IH =  1/5*( IH1 + IH2 + IH3 + IH6 + IH7)
by iso_code, sort: egen FirstTimeIH = min(cond(IH != . , datemdy, .))
format FirstTimeIH %d
replace IH = 0 if FirstTimeIH > datemdy & FirstTimeIH != .
*drop FirstTimeIH
*Rest mean
bysort datemdy: egen mean_IC = mean(IC)
gen IC_Rest = IC - mean_IC 
sort iso_code year datemdy 
save "${path1}\Bases\Intermediate\TrackerOxford-4.13.dta", replace

********************************************************************************
********************************************************************************
/*******************************************************************************
                            IC Rest Neighbours  
*******************************************************************************/
********************************************************************************
*Contiguous; Cultural(Lenguage and Colony); Own Rose 
********************************************************************************
clear all
use "${path1}\Bases\Intermediate\TrackerOxford-4.13.dta", clear
*Itero creacion de variables 
keep iso_code datemdy IC_Rest 
rename IC_Rest  IC
sort iso_code datemdy
list iso_code if missing(IC) & datemdy == 22150
drop if missing(IC)
reshape wide IC, i(datemdy)  j(iso_code) string // Gen columns with iso_code and rows with time  //std_IC
sort datemdy
save "${path1}\Bases\Intermediate\datemdy-ICRestbycountry.dta", replace
********************************************************************************
********************************************************************************
/*******************************************************************************
                            IC Neighbours  
*******************************************************************************/
********************************************************************************
*Contiguous; Cultural(Lenguage and Colony); Own Rose 
********************************************************************************
clear all
use "${path1}\Bases\Intermediate\TrackerOxford-4.13.dta", clear
*Itero creacion de variables 
keep iso_code datemdy IC
sort iso_code datemdy
list iso_code if missing(IC) & datemdy == 22150
drop if missing(IC)
reshape wide IC, i(datemdy)  j(iso_code) string // Gen columns with iso_code and rows with time  //std_IC
sort datemdy
save "${path1}\Bases\Intermediate\datemdy-ICbycountry.dta", replace
/*******************************************************************************
                       IC Neighbours by border
*******************************************************************************/
/*******************************************************************************
Gen B dta of neighbours, datemdy in rows, iso_code in columns
Steps:
1_ Keep two columns: iso_code and datemdy
2_ Gen list of iso_code
3_ Gen iso_code columns with for each in list (step 2). Result B (nxt,n) 
 b Delete columns if IC not available
Replacement
4_ Gen 42 list of neighbours 1 for each country
5_ Replace equal (1/number of neighbours) if variable is in list of neighbours     
*******************************************************************************/
*1
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear 
keep iso_code datemdy 
*2
levelsof iso_code, local(countries)    
sort iso_code datemdy
*3
sort iso_code datemdy
foreach i of local countries {
      gen `i' = 0
} 
local NotAvailable AIA ARM ATG COM CUW FSM GNB GNQ GRD KNA LCA LIE MDV MKD MHL MNE PRK STP TTO VAT VCT WSM
foreach s of local NotAvailable {
      drop `s'
} 
*4
local AUS  //Island 
local AUT CHE CZE DEU HUN ITA SVK SVN  
local BEL DEU FRA LUX NLD
local BRA ARG BOL COL GUY PRY PER SUR URY VEN
local CAN USA
local CRI NIC PAN 
local CHE DEU AUT FRA ITA  //LIE 
local CHL ARG BOL PER
local CHN AFG BTN HKG IND KAZ KGZ LAO MAC MMR MNG NPL PAK RUS TJK VNM  //PRK NA
local COL BRA ECU PAN PER VEN
local CZE DEU AUT FRA ITA  //LIE
local DEU AUT BEL DNK FRA LUX NLD POL CZE CHE
local DNK DEU
local ESP AND FRA MAR PRT 
local EST LVA RUS 
local FIN NOR RUS SWE 
local FRA DEU AND BEL ESP ITA LUX MCO CHE     //BRA SRN NLD 
local GBR IRL
local GRC ALB BGR TUR  //MKD 
local HUN AUT HRV SVK SVN ROU SRB UKR
local IDN MYS PNG TLS
local IND BGD BTN CHN MMR NPL PAK
local IRL GBR
local ISR EGY JOR LBN SYR PSE
local ITA AUT SVN FRA SMR CHE   //VAT 
local JPN //Island 
local KOR  //PRK
local LTU BLR LVA POL RUS //Kaliningrado 
local LUX DEU BEL  //FRA Saint Martin 
local LVA BLR EST LTU RUS 
local MEX USA GTM BLZ 
local NLD DEU BEL //FRA
local NOR FIN RUS SWE 
local NZL //Island 
local POL BLR CZE DEU LTU RUS SVK UKR //Kaliningrado 
local PRT ESP
local RUS AZE BLR CHN EST FIN GEO KAZ  LTU LVA MNG NOR POL UKR   //Kaliningrado PRK
local SVK AUT CZE HUN POL UKR 
local SVN AUT HRV HUN ITA
local SWE FIN NOR 
local TUR  AZE BGR GEO GRC IRN IRQ SYR  //ARM
local USA CAN MEX 
local ZAF BWA LSO MOZ NAM SWZ ZWE    
*5
local list AUS AUT BEL BRA CAN CHE CHL CHN COL CZE DEU DNK ESP EST FIN FRA GBR GRC HUN IDN IND IRL ISR ITA JPN KOR LTU LUX LVA MEX NLD NOR NZL POL PRT RUS SVK SVN SWE TUR USA ZAF     

 foreach j of local list{

foreach i of local `j'{
  replace `i' = 1 if iso_code == "`j'"
}

}

egen N = rowtotal(ABW-ZWE)

foreach x of varlist ABW-ZWE {

replace `x'=  `x'/N if N != 0
}
/*******************************************************************************
Gen C B;A: B(datemdy-Weights)(nxt,n) A(datemdy-ICbycountry)(nxt,n) 
1_ Merge B-A
2_ Gen columns of weighted IC for each neighbour
3_ Sum weighted IC
4_ Keep iso_code datemdy IC_Neighbours 
*******************************************************************************/
merge m:m datemdy using "${path1}\Bases\Intermediate\datemdy-ICRestbycountry.dta"
sort iso_code datemdy
quietly describe  ABW - ZWE, varlist

local vars = r(varlist)

foreach y of varlist `vars'{

gen W_IC_`y' = `y' * IC`y' if IC`y' != .            

}

gen IC_Neighbours_border = 0 

quietly describe  W_IC_*, varlist
local vars = r(varlist)

foreach v of varlist `vars' { 
	replace IC_Neighbours_border = IC_Neighbours_border + `v' if  `v' != .
} 
sort iso_code datemdy
keep iso_code datemdy IC_Neighbours_border
keep if iso_code == "AUS" | iso_code == "AUT" | iso_code == "BEL" | iso_code == "BRA" | iso_code == "CAN" | iso_code == "CHE" | iso_code == "CHL" | iso_code == "CHN" | iso_code == "COL" | iso_code == "CRI" | iso_code == "CZE" | iso_code == "DEU" | iso_code == "DNK" | iso_code == "ESP" | iso_code == "EST" | iso_code == "FIN" | iso_code == "FRA" | iso_code == "GBR" | iso_code == "GRC" | iso_code == "HUN" | iso_code == "IDN" | iso_code == "IND" | iso_code == "IRL" | iso_code == "ISR" | iso_code == "ITA" | iso_code == "JPN" | iso_code == "KOR" | iso_code == "LTU" | iso_code == "LUX" | iso_code == "LVA" | iso_code == "MEX" | iso_code == "NLD" | iso_code == "NOR" | iso_code == "NZL" | iso_code == "POL" | iso_code == "PRT" | iso_code == "RUS" | iso_code == "SVK" | iso_code == "SVN" | iso_code == "SWE" | iso_code == "TUR" | iso_code == "USA" | iso_code == "ZAF"
sort iso_code datemdy
save "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours-Border.dta", replace








*AGREGAR 






********************************************************************************
/*******************************************************************************
                        New Health Variables  
*******************************************************************************/
******************************************************************************** 
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\CovidData-OurWorldinData-23.2.21.dta"
sort iso_code year datemdy
*
drop if _merge == 2
drop _merge
sort iso_code year datemdy     
/*                               Trend                                        */
* Tendencia con conteo a partir del caso 100
*Localizo primer obs para rempazar con 0 valores anteriores (.)
by iso_code, sort: egen FirstTotalCases = min(cond(total_cases != ., datemdy, .))
format FirstTotalCases %d
*Remplazo con . en caso de no haber casos, con 0 previo al primer caso 
replace total_cases = 0 if FirstTotalCases != . & FirstTotalCases > datemdy 
*Localizo primer observación de 100 o más casos
by iso_code, sort: egen FirstTimeMoreThan100 = min(cond(total_cases>=100 & total_cases!=., datemdy, .))
format FirstTimeMoreThan100 %d
sort iso_code year  datemdy 
*Genero conteo                                                                               
g Trend_100cases = .
replace Trend_100cases = datemdy - FirstTimeMoreThan100 if  FirstTimeMoreThan100 !=.
replace Trend_100cases = . if FirstTimeMoreThan100 == .
replace Trend_100cases = 0 if FirstTimeMoreThan100 !=. & FirstTimeMoreThan100 > datemdy
*Dummy more than 100
g Pandemic = . 
replace Pandemic = 0 if FirstTimeMoreThan100 > datemdy & FirstTimeMoreThan100 !=.
replace Pandemic = 1 if FirstTimeMoreThan100 <= datemdy & FirstTimeMoreThan100 !=.
/*******************************************************************************
0s before first case/death (if not missing)
*******************************************************************************/
*New Cases
sort iso_code year  datemdy 
by iso_code, sort: egen FirstTimeNewCase = min(cond(new_cases != ., datemdy, .))
format FirstTimeNewCase %d 
sort iso_code year  datemdy 
replace new_cases = 0 if FirstTimeNewCase > datemdy & FirstTimeNewCase != .
replace new_cases_per_million = 0 if FirstTimeNewCase > datemdy & FirstTimeNewCase != .
*New Death
by iso_code, sort: egen FirstTimeNewDeath= min(cond(new_deaths != ., datemdy, .))
format FirstTimeNewDeath %d
sort iso_code year  datemdy 
replace new_deaths = 0 if FirstTimeNewDeath > datemdy & FirstTimeNewDeath != .
replace new_deaths_per_million = 0 if FirstTimeNewDeath > datemdy & FirstTimeNewDeath != .
********************************************************************************  
/*               15-day moving average if unless 1 obs in 15 days             */
********************************************************************************  
*New cases 
order iso_code datemdy FirstTimeNewCase FirstTimeNewDeath                                         
sort iso_code year datemdy
bys iso_code: asrol new_cases, wind(datemdy 15) stat(mean) min(1)
*New cases per million
sort iso_code year datemdy
bys iso_code: asrol new_cases_per_million, wind(datemdy 15) stat(mean) min(1)
*New deaths 
sort iso_code year datemdy
bys iso_code: asrol new_deaths, wind(datemdy 15) stat(mean) min(1)
*New deaths per million 
sort iso_code year datemdy
bys iso_code: asrol new_deaths_per_million, wind(datemdy 15) stat(mean) min(1)
*  Remplazo con 0 valores anteriores a primer observación
replace mean15_new_cases = 0 if FirstTimeNewCase > datemdy & FirstTimeNewCase != .
replace mean15_new_deaths = 0 if FirstTimeNewDeath > datemdy & FirstTimeNewDeath != .
replace mean15_new_cases_per_million = 0 if FirstTimeNewCase > datemdy & FirstTimeNewCase != .
replace mean15_new_deaths_per_million = 0 if FirstTimeNewDeath > datemdy & FirstTimeNewDeath != .
********************************************************************************  
/*                             Lag Mean 15                                     */
********************************************************************************  
*  mean15 deaths and cases  
gen lag_mean15_new_cases = mean15_new_cases[_n-15] 
gen lag_mean15_new_cases_per_million = mean15_new_cases_per_million[_n-15] 
gen lag_mean15_new_deaths = mean15_new_deaths[_n-15] 
gen lag_mean15_new_deaths_per_mill = mean15_new_deaths_per_million[_n-15] 
sort iso_code year datemdy
save "${path1}\Bases\Intermediate\CovidData-4.13.dta", replace


********************************************************************************                                                          
********************************************************************************
*******************************************************************************/
/*                             Main Merge                                     */
********************************************************************************
********************************************************************************                                                          
********************************************************************************
*Complete ISO-Date
clear all
use "${path1}\Bases\Intermediate\IsoCodeDate.dta", clear
sort iso_code year datemdy
*BCI, OECD
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\BCI-04.15.21-short.dta", nogenerate
sort iso_code year datemdy 
order iso_code year quarter month datemdy BCI
*Monetary and Fiscal variables. GDP, BIS ir real, BIS USA ir real
merge m:m iso_code year month datemdy using "${path1}\Bases\Intermediate\FiscalandMonetary_13.4.dta", nogenerate
sort iso_code year month datemdy 
*Women in Parliament, World Bank
merge m:m iso_code year using "${path1}\Bases\Intermediate\WomeninParliament_2.23.21.dta"
drop if _merge == 2 
drop _merge
*Development
merge m:1 iso_code using "${path1}\Bases\Other\iso_development.dta", nogenerate
drop if iso_code == ""
drop iso_code2 DevelopmentCat
*Governance Indicator 
merge m:m iso_code year using "${path1}\Bases\Intermediate\WB_GovIndicators_5.3.21.dta"
drop if _merge == 2 
drop _merge
sort iso_code year datemdy
*GPR
merge m:m iso_code year month using "${path1}\Bases\Intermediate\GPR_5.5.21.dta"
drop if _merge == 2 
drop _merge
sort iso_code year datemdy
*Economic Freedom Heritage
merge m:m iso_code year using "${path1}\Bases\Intermediate\Heritage_5.1.21.dta"
drop if _merge == 2 
drop _merge
sort iso_code year datemdy
*Health, OURWORLDINDATA
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\CovidData-4.13.dta", nogenerate
sort iso_code year datemdy
*Tracker, Oxford
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\TrackerOxford-4.13.dta", nogenerate 
sort iso_code year datemdy 
*DPI
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\DPI_13.4.dta", nogenerate 
sort iso_code year datemdy 
*Contiguous
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours-Border.dta", nogenerate 
sort iso_code year datemdy
*Culture
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_ComLangCol.dta", nogenerate 
sort iso_code year month datemdy
*Culture D
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_ComCult_D.dta", nogenerate 
sort iso_code year month datemdy
*Culture E
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_ComCult_E.dta", nogenerate 
sort iso_code year month datemdy
*Culture DE
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_ComCult_DE.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 5
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_5.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 5 D
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_5_D.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 5 E
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_5_E.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 5 DE
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_5_DE.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 3
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_3.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 3 D
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_3_D.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 3 E
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_3_E.dta", nogenerate 
sort iso_code year month datemdy
*Distance, first 3 DE
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_Dist_3_DE.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 5
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours-OwnRose_5.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 5 D
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_5_D.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 5 E
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_5_E.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 5 DE
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_5_DE.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 3
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours-OwnRose_3.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 3 D
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_3_D.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 3 E
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_3_E.dta", nogenerate 
sort iso_code year month datemdy
*Trade(Rose), first 3 DE
merge m:m iso_code datemdy using "${path1}\Bases\Intermediate\iso_code-datemdy-IC_Neighbours_OwnRose_3_DE.dta", nogenerate 
sort iso_code year month datemdy

********************************************************************************                                                          
********************************************************************************
/*******************************************************************************
                     Changes for final Dataset 
*******************************************************************************/
********************************************************************************                                                          
********************************************************************************

/*******************************************************************************
                    From daily to monthly
*******************************************************************************/
gen day=day(datemdy)
*
by iso_code, sort: egen FirstTimeBCI = min(cond(BCI != ., datemdy, .))
order iso_code year month day datemdy BCI FirstTimeBCI
*
keep if day == 15 & FirstTimeBCI != .
/*******************************************************************************
                          Lag variables
*******************************************************************************/
*                             IC IE IH
by iso_code: gen IC_Lag = IC[_n-1]
by iso_code: gen IC_Rest_Lag = IC_Rest[_n-1]
by iso_code: gen IE_Lag = IE[_n-1]
by iso_code: gen IE1_Lag = IE1[_n-1]
by iso_code: gen IE2_Lag = IE2[_n-1]
by iso_code: gen IH_Lag = IH[_n-1]

by iso_code: gen StringencyIndex_Lag = StringencyIndex[_n-1]
by iso_code: gen EconomicSupportIndex_Lag = EconomicSupportIndex[_n-1]

*                           IC Neighbours
by iso_code: gen IC_Neighbours_border_Lag = IC_Neighbours_border[_n-1]
by iso_code: gen IC_Neighbours_ComCult_Lag = IC_Neighbours_ComCult[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_5_Lag = IC_Neighbours_OwnRose_5[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_3_Lag = IC_Neighbours_OwnRose_3[_n-1]
by iso_code: gen IC_Neighbours_dist_5_Lag = IC_Neighbours_dist_5[_n-1]
by iso_code: gen IC_Neighbours_dist_3_Lag = IC_Neighbours_dist_3[_n-1] 

*D
by iso_code: gen IC_Neighbours_ComCult_D_Lag = IC_Neighbours_ComCult_D[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_5_D_Lag = IC_Neighbours_OwnRose_5_D[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_3_D_Lag = IC_Neighbours_OwnRose_3_D[_n-1]
by iso_code: gen IC_Neighbours_Dist_5_D_Lag = IC_Neighbours_Dist_5_D[_n-1]
by iso_code: gen IC_Neighbours_Dist_3_D_Lag = IC_Neighbours_Dist_3_D[_n-1] 
*E
by iso_code: gen IC_Neighbours_ComCult_E_Lag = IC_Neighbours_ComCult_E[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_5_E_Lag = IC_Neighbours_OwnRose_5_E[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_3_E_Lag = IC_Neighbours_OwnRose_3_E[_n-1]
by iso_code: gen IC_Neighbours_Dist_5_E_Lag = IC_Neighbours_Dist_5_E[_n-1]
by iso_code: gen IC_Neighbours_Dist_3_E_Lag = IC_Neighbours_Dist_3_E[_n-1] 
*DE
by iso_code: gen IC_Neighbours_ComCult_DE_Lag = IC_Neighbours_ComCult_DE[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_5_DE_Lag = IC_Neighbours_OwnRose_5_DE[_n-1]
by iso_code: gen IC_Neighbours_OwnRose_3_DE_Lag = IC_Neighbours_OwnRose_3_DE[_n-1]
by iso_code: gen IC_Neighbours_Dist_5_DE_Lag = IC_Neighbours_Dist_5_DE[_n-1]
by iso_code: gen IC_Neighbours_Dist_3_DE_Lag = IC_Neighbours_Dist_3_DE[_n-1] 

*                         Monetary and policy
by iso_code: gen BIS_real_ir_USA_Lag = BIS_real_ir_USA[_n-1]
by iso_code: gen BIS_real_ir_Lag = BIS_real_ir[_n-1]
by iso_code: gen Gov_Final_Cons_GDP_Lag = Gov_Final_Cons_GDP[_n-3] 
*                           Pol Variables
by iso_code: gen execrlc_Lag = execrlc[_n-1]
*                    Gov Indicators 1 year lagged
by iso_code: gen GovEffect_Lag = GovEffect[_n-12]
by iso_code: gen PolStab_Lag = PolStab[_n-12]
by iso_code: gen RuleofLaw_Lag = RuleofLaw[_n-12]
by iso_code: gen ControlofCorr_Lag = ControlofCorr[_n-12]
*                    Heritage 1 year lagged
by iso_code: gen EconomicFreedom_Lag = EconomicFreedom[_n-1]
by iso_code: gen PropertyRights_Lag = PropertyRights[_n-1]
by iso_code: gen GovernmentIntegrity_Lag = GovernmentIntegrity[_n-1]
by iso_code: gen JudicialEffectiveness_Lag = JudicialEffectiveness[_n-1]
by iso_code: gen TaxBurden_Lag = TaxBurden[_n-1]
by iso_code: gen GovernmentSpending_Lag = GovernmentSpending[_n-1]
by iso_code: gen FiscalHealth_Lag = FiscalHealth[_n-1]
by iso_code: gen BusinessFreedom_Lag = BusinessFreedom[_n-1]
by iso_code: gen LaborFreedom_Lag = LaborFreedom[_n-1]
by iso_code: gen MonetaryFreedom_Lag = MonetaryFreedom[_n-1]
by iso_code: gen TradeFreedom_Lag = TradeFreedom[_n-1]
by iso_code: gen InvestmentFreedom_Lag = InvestmentFreedom[_n-1]
by iso_code: gen FinancialFreedom_Lag = FinancialFreedom[_n-1]
*                             GPR
by iso_code: gen GPR_Lag = GPR[_n-1]

/*******************************************************************************
                       Base Jan2018 - Nov2020
*******************************************************************************/ 
drop if datemdy < 21185 | datemdy > 22280 
/*******************************************************************************
                            Std Variables
*******************************************************************************/
*Date
egen std_date =  std(datemdy)
*                            Deaths 
egen std_m15_new_deaths_per_million =  std(mean15_new_deaths_per_million)
*                     IC IE IH StringencyIndex
egen std_IC=  std(IC)
egen std_IC_Rest =  std(IC_Rest)
egen std_IE=  std(IE)
egen std_IE1=  std(IE1)
egen std_IE2=  std(IE2)
egen std_EconomicSupportIndex =  std(EconomicSupportIndex)
egen std_StringencyIndex =  std(StringencyIndex)
egen std_IH =  std(IH)
*                           IC Neighbours
egen std_IC_Neighbours_border =  std(IC_Neighbours_border)
egen std_IC_Neighbours_ComCult =  std(IC_Neighbours_ComCult)
egen std_IC_Neighbours_dist_5 =  std(IC_Neighbours_dist_5)
egen std_IC_Neighbours_OwnRose_5 =  std(IC_Neighbours_OwnRose_5)
egen std_IC_Neighbours_dist_3 =  std(IC_Neighbours_dist_3)
egen std_IC_Neighbours_OwnRose_3 =  std(IC_Neighbours_OwnRose_3)
*                      IC Neighbours by development
*D
egen std_IC_Neighbours_ComCult_D =  std(IC_Neighbours_ComCult_D)
egen std_IC_Neighbours_Dist_5_D =  std(IC_Neighbours_Dist_5_D)
egen std_IC_Neighbours_OwnRose_5_D =  std(IC_Neighbours_OwnRose_5_D)
egen std_IC_Neighbours_Dist_3_D =  std(IC_Neighbours_Dist_3_D)
egen std_IC_Neighbours_OwnRose_3_D =  std(IC_Neighbours_OwnRose_3_D)
*E 
egen std_IC_Neighbours_ComCult_E =  std(IC_Neighbours_ComCult_E)
egen std_IC_Neighbours_Dist_5_E =  std(IC_Neighbours_Dist_5_E)
egen std_IC_Neighbours_OwnRose_5_E =  std(IC_Neighbours_OwnRose_5_E)
egen std_IC_Neighbours_Dist_3_E =  std(IC_Neighbours_Dist_3_E)
egen std_IC_Neighbours_OwnRose_3_E =  std(IC_Neighbours_OwnRose_3_E)
*DE
egen std_IC_Neighbours_ComCult_DE =  std(IC_Neighbours_ComCult_DE)
egen std_IC_Neighbours_Dist_5_DE =  std(IC_Neighbours_Dist_5_DE)
egen std_IC_Neighbours_OwnRose_5_DE =  std(IC_Neighbours_OwnRose_5_DE)
egen std_IC_Neighbours_Dist_3_DE =  std(IC_Neighbours_Dist_3_DE) 
egen std_IC_Neighbours_OwnRose_3_DE =  std(IC_Neighbours_OwnRose_3_DE)
*                         Monetary and policy
egen std_BIS_real_ir_USA =  std(BIS_real_ir_USA)
egen std_BIS_real_ir = std(BIS_real_ir)
egen std_Gov_Final_Cons_GDP=  std(Gov_Final_Cons_GDP)
/*******************************************************************************
                         Lag Std Variables
*******************************************************************************/
*                   IC IE IH StringencyIndex
egen std_IC_Lag =  std(IC_Lag)

egen std_IC_Rest_Lag  =  std(IC_Rest_Lag)

egen std_IE_Lag =  std(IE_Lag)

egen std_IE1_Lag =  std(IE1_Lag)

egen std_IE2_Lag =  std(IE2_Lag)

egen std_EconomicSupportIndex_Lag  =  std(EconomicSupportIndex_Lag)

egen std_StringencyIndex_Lag  =  std(StringencyIndex_Lag)

egen std_IH_Lag  =  std(IH_Lag)

*                       IC Neighbours
egen std_IC_Neighbours_border_Lag  =  std(IC_Neighbours_border_Lag)
egen std_IC_Neighbours_ComCult_Lag  =  std(IC_Neighbours_ComCult_Lag)
egen std_IC_Neighbours_dist_5_Lag  =  std(IC_Neighbours_dist_5_Lag)
egen std_IC_Neighbours_OwnRose_5_Lag  =  std(IC_Neighbours_OwnRose_5_Lag)
egen std_IC_Neighbours_dist_3_Lag  =  std(IC_Neighbours_dist_3_Lag)
egen std_IC_Neighbours_OwnRose_3_Lag  =  std(IC_Neighbours_OwnRose_3_Lag)
*                      IC Neighbours by development
*D
egen std_IC_Neighbours_ComCult_D_Lag =  std(IC_Neighbours_ComCult_D_Lag)
egen std_IC_Neighbours_Dist_5_D_Lag =  std(IC_Neighbours_Dist_5_D_Lag)
egen std_IC_Neighbours_OR_5_D_Lag =  std(IC_Neighbours_OwnRose_5_D_Lag)
egen std_IC_Neighbours_Dist_3_D_Lag =  std(IC_Neighbours_Dist_3_D_Lag)
egen std_IC_Neighbours_OR_3_D_Lag =  std(IC_Neighbours_OwnRose_3_D_Lag)
*E 
egen std_IC_Neighbours_ComCult_E_Lag =  std(IC_Neighbours_ComCult_E_Lag)
egen std_IC_Neighbours_Dist_5_E_Lag =  std(IC_Neighbours_Dist_5_E_Lag)
egen std_IC_Neighbours_OR_5_E_Lag =  std(IC_Neighbours_OwnRose_5_E_Lag)
egen std_IC_Neighbours_Dist_3_E_Lag =  std(IC_Neighbours_Dist_3_E_Lag)
egen std_IC_Neighbours_OR_3_E_Lag =  std(IC_Neighbours_OwnRose_3_E_Lag)
*DE
egen std_IC_Neighbours_ComCult_DE_Lag =  std(IC_Neighbours_ComCult_DE_Lag)
egen std_IC_Neighbours_Dist_5_DE_Lag =  std(IC_Neighbours_Dist_5_DE_Lag)
egen std_IC_Neighbours_OR_5_DE_Lag =  std(IC_Neighbours_OwnRose_5_DE_Lag)
egen std_IC_Neighbours_Dist_3_DE_Lag =  std(IC_Neighbours_Dist_3_DE_Lag) 
egen std_IC_Neighbours_OR_3_DE_Lag =  std(IC_Neighbours_OwnRose_3_DE_Lag)

*                   Monetary and policy
egen std_BIS_real_ir_USA_Lag  =  std(BIS_real_ir_USA_Lag)
egen std_BIS_real_ir_Lag  = std(BIS_real_ir_Lag)
egen std_Gov_Final_Cons_GDP_Lag =  std(Gov_Final_Cons_GDP_Lag)                  //Ver
*                      Pol Variables
egen std_WomeninParliament_Lag =  std(WomeninParliament_Lag)
*                    Gov Indicators 
egen std_GovEffect_Lag = std(GovEffect_Lag)
egen std_PolStab_Lag = std(PolStab_Lag)
egen std_RuleofLaw_Lag = std(RuleofLaw_Lag)
egen std_ControlofCorr_Lag = std(ControlofCorr_Lag)
*                    Heritage 1 year lagged
*                    Heritage 1 year lagged
egen std_EconomicFreedom_Lag = std(EconomicFreedom_Lag)
egen std_PropertyRights_Lag = std(PropertyRights_Lag)
egen std_GovernmentIntegrity_Lag = std(GovernmentIntegrity_Lag)
egen std_JudicialEffectiveness_Lag = std(JudicialEffectiveness_Lag)
egen std_TaxBurden_Lag = std(TaxBurden_Lag)
egen std_GovernmentSpending_Lag = std(GovernmentSpending_Lag)
egen std_FiscalHealth_Lag = std(FiscalHealth_Lag)
egen std_BusinessFreedom_Lag = std(BusinessFreedom_Lag)
egen std_LaborFreedom_Lag = std(LaborFreedom_Lag)
egen std_MonetaryFreedom_Lag = std(MonetaryFreedom_Lag)
egen std_TradeFreedom_Lag = std(TradeFreedom_Lag)
egen std_InvestmentFreedom_Lag = std(InvestmentFreedom_Lag)
egen std_FinancialFreedom_Lag = std(FinancialFreedom_Lag)
*                          GPR

egen std_GPR_Lag = std(GPR_Lag)
/*******************************************************************************
                         Mean and Median
*******************************************************************************/
bysort Development: egen MeanICbyDevelopment = mean(IC_Lag) if Pandemic == 1 & IC_Lag != .
bysort Development: egen MedianICbyDevelopment= median(IC_Lag) if Pandemic == 1 & IC_Lag != .

bysort Development: egen MeanVoluntarybyDevelopment = mean(mean15_new_deaths_per_million) if Pandemic == 1 & mean15_new_deaths_per_million != .
bysort Development: egen MedianVoluntarybyDevelopment= median(mean15_new_deaths_per_million) if Pandemic == 1 & mean15_new_deaths_per_million != .
sort Development iso_code datemdy 

egen MeanGral = mean(IC_Lag)
egen MedianGral = median(IC_Lag) 
sort iso_code datemdy
bysort datemdy: egen Containment_MonthlyMedian = median(IC_Lag) 
gen Containment_A_B_Median = 0
replace Containment_A_B_Median = 1 if IC_Lag > Containment_MonthlyMedian


sort iso_code datemdy
bysort datemdy: egen Voluntary_MonthlyMedian = median(mean15_new_deaths_per_million) 
sort iso_code datemdy
gen Voluntary_A_B_Median = 0
replace Voluntary_A_B_Median = 1 if mean15_new_deaths_per_million > Voluntary_MonthlyMedian
sort iso_code datemdy

/*******************************************************************************
                 Keep and order variables
********************************************************************************/
sort iso_code datemdy
keep iso_code year month datemdy BCI Trend_100cases Pandemic std_m15_new_deaths_per_million std_IC_Lag IC_Lag IE_Lag std_BIS_real_ir_Lag  std_BIS_real_ir_USA_Lag BIS_real_ir_USA_Lag  std_Gov_Final_Cons_GDP_Lag Gov_Final_Cons_GDP_Lag std_WomeninParliament_Lag execrlc_Lag system Development std_GovEffect_Lag std_PolStab_Lag std_RuleofLaw_Lag std_ControlofCorr_Lag std_EconomicFreedom_Lag std_PropertyRights_Lag std_GovernmentIntegrity_Lag std_JudicialEffectiveness_Lag std_TaxBurden_Lag std_GovernmentSpending_Lag std_FiscalHealth_Lag std_BusinessFreedom_Lag std_LaborFreedom_Lag std_MonetaryFreedom_Lag std_TradeFreedom_Lag std_InvestmentFreedom_Lag std_FinancialFreedom_Lag std_IC_Neighbours_border_Lag std_IC_Neighbours_ComCult_Lag std_IC_Neighbours_dist_5_Lag std_IC_Neighbours_OwnRose_5_Lag std_IC_Neighbours_dist_3_Lag std_IC_Neighbours_OwnRose_3_Lag std_IC_Neighbours_ComCult_D_Lag std_IC_Neighbours_ComCult_E_Lag std_IC_Neighbours_ComCult_DE_Lag std_IC_Neighbours_Dist_5_D_Lag std_IC_Neighbours_Dist_5_E_Lag std_IC_Neighbours_Dist_5_DE_Lag std_IC_Neighbours_OR_5_D_Lag std_IC_Neighbours_OR_5_E_Lag std_IC_Neighbours_OR_5_DE_Lag std_IC_Neighbours_Dist_3_D_Lag std_IC_Neighbours_Dist_3_E_Lag std_IC_Neighbours_Dist_3_DE_Lag std_IC_Neighbours_OR_3_D_Lag std_IC_Neighbours_OR_3_E_Lag std_IC_Neighbours_OR_3_DE_Lag Development Containment_A_B_Median std_GPR_Lag std_IE_Lag std_IE1_Lag std_IE2_Lag Voluntary_A_B_Median  mean15_new_deaths_per_million  BIS_real_ir_Lag 
order iso_code year month datemdy BCI Trend_100cases Pandemic std_m15_new_deaths_per_million std_IC_Lag std_BIS_real_ir_Lag std_BIS_real_ir_USA_Lag std_Gov_Final_Cons_GDP_Lag Gov_Final_Cons_GDP_Lag std_WomeninParliament_Lag execrlc_Lag system Development std_GovEffect_Lag std_PolStab_Lag std_RuleofLaw_Lag std_ControlofCorr_Lag std_EconomicFreedom_Lag std_PropertyRights_Lag std_GovernmentIntegrity_Lag std_JudicialEffectiveness_Lag std_TaxBurden_Lag std_GovernmentSpending_Lag std_FiscalHealth_Lag std_BusinessFreedom_Lag std_LaborFreedom_Lag std_MonetaryFreedom_Lag std_TradeFreedom_Lag std_InvestmentFreedom_Lag std_FinancialFreedom_Lag std_IC_Neighbours_border_Lag std_IC_Neighbours_ComCult_Lag std_IC_Neighbours_dist_5_Lag std_IC_Neighbours_OwnRose_5_Lag std_IC_Neighbours_dist_3_Lag std_IC_Neighbours_OwnRose_3_Lag std_IC_Neighbours_ComCult_D_Lag std_IC_Neighbours_ComCult_E_Lag std_IC_Neighbours_ComCult_DE_Lag std_IC_Neighbours_Dist_5_D_Lag std_IC_Neighbours_Dist_5_E_Lag std_IC_Neighbours_Dist_5_DE_Lag std_IC_Neighbours_OR_5_D_Lag std_IC_Neighbours_OR_5_E_Lag std_IC_Neighbours_OR_5_DE_Lag std_IC_Neighbours_Dist_3_D_Lag std_IC_Neighbours_Dist_3_E_Lag std_IC_Neighbours_Dist_3_DE_Lag std_IC_Neighbours_OR_3_D_Lag std_IC_Neighbours_OR_3_E_Lag std_IC_Neighbours_OR_3_DE_Lag Development Containment_A_B_Median std_GPR_Lag std_IE_Lag std_IE1_Lag std_IE2_Lag Voluntary_A_B_Median  mean15_new_deaths_per_million BIS_real_ir_Lag 
********************************************************************************                                                          
********************************************************************************
/*******************************************************************************
                             Labels
*******************************************************************************/
********************************************************************************                                                          
********************************************************************************
label variable std_m15_new_deaths_per_million "Deaths/Million"
label variable Trend_100cases "Trend"
label variable std_IC_Lag "Comp Containment"
label variable IC_Lag "Comp Containment"
label variable std_IE_Lag "Eco Support"
label variable IE_Lag "Eco Support"
label variable std_Gov_Final_Cons_GDP_Lag "Gov Consumption"
label variable Gov_Final_Cons_GDP_Lag "Gov Consumption"
label variable std_BIS_real_ir_Lag "Dom Mon Policy Rate "
label variable BIS_real_ir_Lag "Dom Mon Policy Rate "
label variable std_BIS_real_ir_USA_Lag "US Policy rate"
label variable execrlc_Lag "Pol Orientation"
label variable system "Gov System"
label variable std_WomeninParliament_Lag "Women Parliament"
label variable std_IC_Neighbours_ComCult_Lag "W_{C} x IC"
label variable std_IC_Neighbours_dist_5_Lag "W_{G_5} x IC"
label variable std_IC_Neighbours_OwnRose_5_Lag "W_{E_5} x IC"
label variable std_IC_Neighbours_dist_3_Lag "W_{G_3} x IC"
label variable std_IC_Neighbours_OwnRose_3_Lag "W_{E_3} x IC"

label variable std_IC_Neighbours_ComCult_D_Lag "W_{C} D x IC"
label variable std_IC_Neighbours_ComCult_E_Lag "W_{C} E x IC"
label variable std_IC_Neighbours_ComCult_DE_Lag "W_{C} D-E x IC"

label variable std_IC_Neighbours_Dist_3_D_Lag "W_{G_3} D x IC"
label variable std_IC_Neighbours_Dist_3_E_Lag "W_{G_3} E x IC"
label variable std_IC_Neighbours_Dist_3_DE_Lag "W_{G_3} D-E x IC"

label variable std_IC_Neighbours_OR_3_D_Lag "W_{E_3} D x IC"
label variable std_IC_Neighbours_OR_3_E_Lag "W_{E_3} E x IC"
label variable std_IC_Neighbours_OR_3_DE_Lag "W_{E_3} DE x IC"
/*                         Labels for values                                  */
*Write labels
label define execrlc 0 "Other" 1 "Right"  2 "Center"  3 "Left" 4 "No Executive"
label define system 2 "Parliamentary"  1 "Assembly-elected President" 0 "Presidential" 
label define Containment_A_B_Median 1 "Above" 0 "Below" 
label define Voluntary_A_B_Median 1 "Above" 0 "Below" 
*Assign Labels
label values execrlc execrlc
label values system system
label values Containment_A_B_Median Containment_A_B_Median
/*******************************************************************************
                       Base Jan2018 - Dec2020
********************************************************************************/
save "${path1}\Stata\Final Dta\Base-Jan2018-Dec2020-4.15.21.dta", replace

